@@ -1,11 +1,11 @@
 var NAVTREEINDEX0 =
 {
-"Apollonius_graph_2_2ag2_exact_traits_8cpp-example.html":[6,0],
-"Apollonius_graph_2_2ag2_exact_traits_sqrt_8cpp-example.html":[6,1],
-"Apollonius_graph_2_2ag2_filtered_traits_no_hidden_8cpp-example.html":[6,2],
-"Apollonius_graph_2_2ag2_hierarchy_8cpp-example.html":[6,3],
-"annotated.html":[5],
-"citelist.html":[4],
+"Apollonius_graph_2_2ag2_exact_traits_8cpp-example.html":[4,0],
+"Apollonius_graph_2_2ag2_exact_traits_sqrt_8cpp-example.html":[4,1],
+"Apollonius_graph_2_2ag2_filtered_traits_no_hidden_8cpp-example.html":[4,2],
+"Apollonius_graph_2_2ag2_hierarchy_8cpp-example.html":[4,3],
+"annotated.html":[3],
+"citelist.html":[2],
 "classApolloniusGraphDataStructure__2.html":[1,0,0,0],
 "classApolloniusGraphDataStructure__2.html#af56c258abf85d039c10ec5774b1b75cf":[1,0,0,0,1],
 "classApolloniusGraphDataStructure__2.html#af5e25af7614c1586ab8851275e3df5fb":[1,0,0,0,0],
@@ -91,11 +91,12 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Apollonius__graph__2.html#a03a9c34a198c73ce1604723d4c4926ff":[1,0,1,22],
 "classCGAL_1_1Apollonius__graph__2.html#a040616ba5d85f21114b5d9f66f94f975":[1,0,1,34],
 "classCGAL_1_1Apollonius__graph__2.html#a0676c730d2f8a39fbf85cff6ba28d856":[1,0,1,49],
-"classCGAL_1_1Apollonius__graph__2.html#a0acce08cdfbab0e1b317b7d027b5073a":[1,0,1,33],
 "classCGAL_1_1Apollonius__graph__2.html#a0c52fcbb3b25be0c6b78d4ae68f6661a":[1,0,1,9],
+"classCGAL_1_1Apollonius__graph__2.html#a0c6f7e8f89f2b15cd1f07c11697c138c":[1,0,1,77],
 "classCGAL_1_1Apollonius__graph__2.html#a0d2673ad1501aebdebecb504d965a40d":[1,0,1,28],
 "classCGAL_1_1Apollonius__graph__2.html#a105e4545eccd9d77d56bc427390b1497":[1,0,1,56],
 "classCGAL_1_1Apollonius__graph__2.html#a17245aed36840bee031fc4fa908d2450":[1,0,1,19],
+"classCGAL_1_1Apollonius__graph__2.html#a17e25341b1e9d805a18e5e7968f5331f":[1,0,1,84],
 "classCGAL_1_1Apollonius__graph__2.html#a186d8f58c9f8835e75f3bd9900e42925":[1,0,1,44],
 "classCGAL_1_1Apollonius__graph__2.html#a1a980bb005f7609fe901793c14e029eb":[1,0,1,0],
 "classCGAL_1_1Apollonius__graph__2.html#a1e780c09c97d949d3425144a8cc81e1a":[1,0,1,12],
@@ -103,36 +104,38 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Apollonius__graph__2.html#a246db3669d7f3f37b5b41db82b3bff93":[1,0,1,55],
 "classCGAL_1_1Apollonius__graph__2.html#a25f6977dceb8fd21143edcf978c04f02":[1,0,1,53],
 "classCGAL_1_1Apollonius__graph__2.html#a26800688e5691e8a926568addb7cdbbe":[1,0,1,47],
+"classCGAL_1_1Apollonius__graph__2.html#a2a701a24e0c0a5c4f54383b342e5685d":[1,0,1,78],
 "classCGAL_1_1Apollonius__graph__2.html#a2abda67bf614ad219266188bd87b8006":[1,0,1,59],
-"classCGAL_1_1Apollonius__graph__2.html#a304f5fe797914ddda090095ece7fdd7d":[1,0,1,39],
-"classCGAL_1_1Apollonius__graph__2.html#a30a25b908f475dc7c495a06799a8a11a":[1,0,1,62],
+"classCGAL_1_1Apollonius__graph__2.html#a2fa082ea432ff8cf0e2a1714edb64ea6":[1,0,1,37],
+"classCGAL_1_1Apollonius__graph__2.html#a304f5fe797914ddda090095ece7fdd7d":[1,0,1,40],
+"classCGAL_1_1Apollonius__graph__2.html#a30a25b908f475dc7c495a06799a8a11a":[1,0,1,64],
 "classCGAL_1_1Apollonius__graph__2.html#a30c5eec12ceba7c32c3156f84834f07e":[1,0,1,30],
 "classCGAL_1_1Apollonius__graph__2.html#a32531acecde7b014ba780c4328ed519d":[1,0,1,61],
-"classCGAL_1_1Apollonius__graph__2.html#a36820d88501404365245c6a7f7fca573":[1,0,1,65],
+"classCGAL_1_1Apollonius__graph__2.html#a36820d88501404365245c6a7f7fca573":[1,0,1,69],
 "classCGAL_1_1Apollonius__graph__2.html#a3969c0696ecb5a405a1a01a459c5b6df":[1,0,1,10],
-"classCGAL_1_1Apollonius__graph__2.html#a3dfe2224421f97d1211a91842d2de89b":[1,0,1,38],
+"classCGAL_1_1Apollonius__graph__2.html#a3e6ee40ec025851112e67338f1613b0e":[1,0,1,79],
 "classCGAL_1_1Apollonius__graph__2.html#a42b527855a0d86c39666fadbffe35a0e":[1,0,1,1],
 "classCGAL_1_1Apollonius__graph__2.html#a4417369c58be047f0159259f4a679a9e":[1,0,1,14],
 "classCGAL_1_1Apollonius__graph__2.html#a4a54f07541f4ef6fa55ac47cc260b619":[1,0,1,5],
+"classCGAL_1_1Apollonius__graph__2.html#a4af1241444a6f3f0d7060f43d92afd73":[1,0,1,35],
 "classCGAL_1_1Apollonius__graph__2.html#a4c2e91040f1c353a7b611b55614bcf79":[1,0,1,11],
 "classCGAL_1_1Apollonius__graph__2.html#a4c7ae4fbb71648098764eaefb3f89b8a":[1,0,1,42],
-"classCGAL_1_1Apollonius__graph__2.html#a4fb0275444193c09ffaacacaf3e57b40":[1,0,1,66],
+"classCGAL_1_1Apollonius__graph__2.html#a4fb0275444193c09ffaacacaf3e57b40":[1,0,1,67],
 "classCGAL_1_1Apollonius__graph__2.html#a50982d21aad7b712945046696c71f13f":[1,0,1,82],
-"classCGAL_1_1Apollonius__graph__2.html#a54e69c37af46e4cb7f8e6a18982325a7":[1,0,1,84],
 "classCGAL_1_1Apollonius__graph__2.html#a5b2a9454def8fbd012cf7fbd976989d7":[1,0,1,31],
+"classCGAL_1_1Apollonius__graph__2.html#a5c663700543fdf1850642be667068799":[1,0,1,38],
 "classCGAL_1_1Apollonius__graph__2.html#a5fd4209127d34c18ac0885520aab5520":[1,0,1,6],
 "classCGAL_1_1Apollonius__graph__2.html#a61636138d13c212ff2a6dd4ff5f816c9":[1,0,1,18],
 "classCGAL_1_1Apollonius__graph__2.html#a67efc48a9fdc072f18176cf8b2d1bf4f":[1,0,1,2],
 "classCGAL_1_1Apollonius__graph__2.html#a6935414a5009edc49af24e8100deed54":[1,0,1,7],
-"classCGAL_1_1Apollonius__graph__2.html#a6e6e1b20ab5018c96e4b0ed2c0f0ee00":[1,0,1,40],
-"classCGAL_1_1Apollonius__graph__2.html#a6f98fefa3d3e46720b190916b18989ed":[1,0,1,78],
+"classCGAL_1_1Apollonius__graph__2.html#a6b4717e54ecb1feffe55b5a85b5596bf":[1,0,1,51],
+"classCGAL_1_1Apollonius__graph__2.html#a6e6e1b20ab5018c96e4b0ed2c0f0ee00":[1,0,1,39],
+"classCGAL_1_1Apollonius__graph__2.html#a76c0ba944717855d9de8dd6adc5ddb2b":[1,0,1,36],
 "classCGAL_1_1Apollonius__graph__2.html#a77b430b6cf2e494cf14099e2a0054c1b":[1,0,1,25],
 "classCGAL_1_1Apollonius__graph__2.html#a7c2be7467b149c7c76eab8ea3b1e2d33":[1,0,1,20],
-"classCGAL_1_1Apollonius__graph__2.html#a7ce7150ab7952a263a6a02284febe42f":[1,0,1,37],
 "classCGAL_1_1Apollonius__graph__2.html#a7dd7566a809e4940560d3f4ef9b7578c":[1,0,1,72],
-"classCGAL_1_1Apollonius__graph__2.html#a82b53618d81c23d3b8f250fdbf942827":[1,0,1,69],
-"classCGAL_1_1Apollonius__graph__2.html#a8653279895dc79f2689d907d28f4d1f9":[1,0,1,77],
-"classCGAL_1_1Apollonius__graph__2.html#a8732f47ec88a3132acb254c96e47ffb2":[1,0,1,51],
+"classCGAL_1_1Apollonius__graph__2.html#a82b53618d81c23d3b8f250fdbf942827":[1,0,1,66],
+"classCGAL_1_1Apollonius__graph__2.html#a83e2ffdb51bdbade565ef5f04f842bf3":[1,0,1,33],
 "classCGAL_1_1Apollonius__graph__2.html#a96f40373b26f5f54f43459866589ce9c":[1,0,1,26],
 "classCGAL_1_1Apollonius__graph__2.html#a9754175ffe172527164a2aa776153be9":[1,0,1,73],
 "classCGAL_1_1Apollonius__graph__2.html#a976247d6a042d6715e1f534d8ad97f8b":[1,0,1,71],
@@ -145,26 +148,23 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Apollonius__graph__2.html#ab22fcb7373318bd74c0569988c7f0df6":[1,0,1,27],
 "classCGAL_1_1Apollonius__graph__2.html#ab2f2378456fe1cac1e2983ca59c720a4":[1,0,1,85],
 "classCGAL_1_1Apollonius__graph__2.html#ab6d44c4ba3fca16592a6a75eefec3142":[1,0,1,43],
-"classCGAL_1_1Apollonius__graph__2.html#ab6e1c26710e0f262b904ec9b262553de":[1,0,1,63],
+"classCGAL_1_1Apollonius__graph__2.html#ab6e1c26710e0f262b904ec9b262553de":[1,0,1,62],
 "classCGAL_1_1Apollonius__graph__2.html#ab79b54196229b0e316f31087b6cdd7b0":[1,0,1,58],
-"classCGAL_1_1Apollonius__graph__2.html#abc4f7611ab12198d9563f4582a09de64":[1,0,1,79],
 "classCGAL_1_1Apollonius__graph__2.html#abd505d277047969aac281c3b06d3024e":[1,0,1,74],
-"classCGAL_1_1Apollonius__graph__2.html#ac10e77936155bb1710d70d47f4d6900f":[1,0,1,68],
+"classCGAL_1_1Apollonius__graph__2.html#ac10e77936155bb1710d70d47f4d6900f":[1,0,1,65],
 "classCGAL_1_1Apollonius__graph__2.html#ac49e5e5289682d991ea051327a4c0d8f":[1,0,1,21],
-"classCGAL_1_1Apollonius__graph__2.html#ac664a5f7ccbf3a5ba0218408d92e492f":[1,0,1,36],
 "classCGAL_1_1Apollonius__graph__2.html#acf04fd992512b8fc8ad6087954e4495a":[1,0,1,60],
 "classCGAL_1_1Apollonius__graph__2.html#ad290e2f58373af8dfd04b083540af35f":[1,0,1,41],
 "classCGAL_1_1Apollonius__graph__2.html#ad2c9b1e5cc26b9a09a2f3c3214d8d824":[1,0,1,81],
 "classCGAL_1_1Apollonius__graph__2.html#ad4fddfda832750c89647807451ae757e":[1,0,1,83],
 "classCGAL_1_1Apollonius__graph__2.html#adc99b3b3a8d7adc7f5b4e38a21733985":[1,0,1,3],
 "classCGAL_1_1Apollonius__graph__2.html#ade765de09304a43067546280f0302003":[1,0,1,16],
-"classCGAL_1_1Apollonius__graph__2.html#ae0d57f5e4c6af866fd2fad76ef91d652":[1,0,1,64],
-"classCGAL_1_1Apollonius__graph__2.html#ae1b60cbcf234a1bc34b7f53fd29c3c60":[1,0,1,35],
+"classCGAL_1_1Apollonius__graph__2.html#ae0d57f5e4c6af866fd2fad76ef91d652":[1,0,1,63],
 "classCGAL_1_1Apollonius__graph__2.html#ae1ec57a6ed30e596614d7fa9c801ee8c":[1,0,1,46],
 "classCGAL_1_1Apollonius__graph__2.html#ae2308f8e4ad50c30969cffe986ffa2f7":[1,0,1,50],
 "classCGAL_1_1Apollonius__graph__2.html#ae737f9780b8e82660cf5cba2e91fa6ab":[1,0,1,54],
 "classCGAL_1_1Apollonius__graph__2.html#aed821e45423a5b176a35e8a9de4756bd":[1,0,1,70],
-"classCGAL_1_1Apollonius__graph__2.html#aeeea392554f6977a65d6c46d10bcf51f":[1,0,1,67],
+"classCGAL_1_1Apollonius__graph__2.html#aeeea392554f6977a65d6c46d10bcf51f":[1,0,1,68],
 "classCGAL_1_1Apollonius__graph__2.html#aef591204a5abd776cd7717b258b52f69":[1,0,1,15],
 "classCGAL_1_1Apollonius__graph__2.html#af1c92a3799648b599b776887d3b05435":[1,0,1,57],
 "classCGAL_1_1Apollonius__graph__2.html#af292b6d506335a271ece345ee9041523":[1,0,1,32],
@@ -178,49 +178,48 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Apollonius__graph__filtered__traits__2.html":[1,0,2],
 "classCGAL_1_1Apollonius__graph__filtered__traits__2.html#a5d8f701b516d381f215298d4ce479454":[1,0,2,0],
 "classCGAL_1_1Apollonius__graph__filtered__traits__2.html#aa758570262d4ab2793cbb274f06fcb21":[1,0,2,1],
-"classCGAL_1_1Apollonius__graph__filtered__traits__2.html#adaeb94fbd457c77d5de16f515c5a5164":[1,0,2,2],
+"classCGAL_1_1Apollonius__graph__filtered__traits__2.html#ac10f1c20a70046edc72fa6b2e6a22cb6":[1,0,2,2],
 "classCGAL_1_1Apollonius__graph__hierarchy__2.html":[1,0,3],
 "classCGAL_1_1Apollonius__graph__hierarchy__2.html#a03e2c9d08a1aaffcdc08b9339390686e":[1,0,3,0],
 "classCGAL_1_1Apollonius__graph__hierarchy__2.html#a0612cee07f0f84f69b4e6e359ea20b6f":[1,0,3,9],
 "classCGAL_1_1Apollonius__graph__hierarchy__2.html#a08a6fb18d4560cce23fe15bd0e0f78cb":[1,0,3,16],
-"classCGAL_1_1Apollonius__graph__hierarchy__2.html#a0eaa28df7025c5f0899bb9c7fb721458":[1,0,3,6],
+"classCGAL_1_1Apollonius__graph__hierarchy__2.html#a0eaa28df7025c5f0899bb9c7fb721458":[1,0,3,8],
+"classCGAL_1_1Apollonius__graph__hierarchy__2.html#a10bc94c6da1a8e37f367c562cb40a852":[1,0,3,13],
 "classCGAL_1_1Apollonius__graph__hierarchy__2.html#a1dc064a2c574f6e2f9616288a14219fc":[1,0,3,15],
 "classCGAL_1_1Apollonius__graph__hierarchy__2.html#a38e31fe1bc3dfc64192bbf7699fe10ad":[1,0,3,5],
-"classCGAL_1_1Apollonius__graph__hierarchy__2.html#a4fbd488b397fdc3770ef068cd70fdece":[1,0,3,13],
 "classCGAL_1_1Apollonius__graph__hierarchy__2.html#a55ac85ac491b3bda8e1aa63030c241f4":[1,0,3,4],
-"classCGAL_1_1Apollonius__graph__hierarchy__2.html#a62a8669977b4c5b0e91aa877f1316632":[1,0,3,12],
+"classCGAL_1_1Apollonius__graph__hierarchy__2.html#a56674948182e2f9aac93f3c2c2f94312":[1,0,3,14],
+"classCGAL_1_1Apollonius__graph__hierarchy__2.html#a58071ada6866761daf8815914e6bbc36":[1,0,3,12],
 "classCGAL_1_1Apollonius__graph__hierarchy__2.html#a7f389883387f80c8069b0cea9ea15ca4":[1,0,3,3],
-"classCGAL_1_1Apollonius__graph__hierarchy__2.html#a84c03b88d5492c0261cef7ebc17b520d":[1,0,3,14],
 "classCGAL_1_1Apollonius__graph__hierarchy__2.html#aa478cd80c93481b79720e7c6e4fa9bd4":[1,0,3,2],
 "classCGAL_1_1Apollonius__graph__hierarchy__2.html#aa970de0db668f3822db8bd9695258edf":[1,0,3,10],
-"classCGAL_1_1Apollonius__graph__hierarchy__2.html#ac51880e521aaaf257f44f082a73ac36b":[1,0,3,7],
+"classCGAL_1_1Apollonius__graph__hierarchy__2.html#ac51880e521aaaf257f44f082a73ac36b":[1,0,3,6],
 "classCGAL_1_1Apollonius__graph__hierarchy__2.html#acae1ba0c79da4e1820951cc1c1bbe404":[1,0,3,11],
 "classCGAL_1_1Apollonius__graph__hierarchy__2.html#ad46364f1b6f577f641f31c815fa63be4":[1,0,3,1],
-"classCGAL_1_1Apollonius__graph__hierarchy__2.html#aef39ca94a20a5bdbbdcd53374e8731ae":[1,0,3,8],
+"classCGAL_1_1Apollonius__graph__hierarchy__2.html#aef39ca94a20a5bdbbdcd53374e8731ae":[1,0,3,7],
 "classCGAL_1_1Apollonius__graph__hierarchy__vertex__base__2.html":[1,0,4],
 "classCGAL_1_1Apollonius__graph__hierarchy__vertex__base__2.html#a3474918838c96c410c791e944945f7a1":[1,0,4,2],
 "classCGAL_1_1Apollonius__graph__hierarchy__vertex__base__2.html#a39e6ec8dba29aed20acf288bd95e747c":[1,0,4,1],
 "classCGAL_1_1Apollonius__graph__hierarchy__vertex__base__2.html#aab59de4a4790178a36a35bcf2df58556":[1,0,4,0],
 "classCGAL_1_1Apollonius__graph__traits__2.html":[1,0,5],
+"classCGAL_1_1Apollonius__graph__traits__2.html#a1093dcfe5fbb546c443a35cf9f2a0c40":[1,0,5,2],
 "classCGAL_1_1Apollonius__graph__traits__2.html#ae0488dd972f835226c48c04a4191e08e":[1,0,5,0],
-"classCGAL_1_1Apollonius__graph__traits__2.html#aed925ab5588918419385ecdbb4c7e5a5":[1,0,5,2],
 "classCGAL_1_1Apollonius__graph__traits__2.html#afb17a8538e91e7fefcc17664a94deca0":[1,0,5,1],
 "classCGAL_1_1Apollonius__graph__vertex__base__2.html":[1,0,6],
 "classCGAL_1_1Apollonius__graph__vertex__base__2.html#a43fa98ecae0bb4db79f9c006ae09e93d":[1,0,6,1],
 "classCGAL_1_1Apollonius__graph__vertex__base__2.html#acbabb6d26d4d8938bde5bbd6c6e467eb":[1,0,6,2],
 "classCGAL_1_1Apollonius__graph__vertex__base__2.html#adbeac293aafa00c6197aad35f537e4ab":[1,0,6,0],
 "classCGAL_1_1Apollonius__site__2.html":[1,0,7],
-"classCGAL_1_1Apollonius__site__2.html#a0179ce70c2e5ca7222abbdf2932d0862":[1,0,7,3],
+"classCGAL_1_1Apollonius__site__2.html#a0179ce70c2e5ca7222abbdf2932d0862":[1,0,7,2],
 "classCGAL_1_1Apollonius__site__2.html#a2d4a25cf4ea786b62ede0876060a21ad":[1,0,7,1],
 "classCGAL_1_1Apollonius__site__2.html#a983005bc02675e9dce25d4308cf7a39b":[1,0,7,0],
-"classCGAL_1_1Apollonius__site__2.html#ab4a6eec990e7a3f271396c6d511e64aa":[1,0,7,2],
+"classCGAL_1_1Apollonius__site__2.html#ab4a6eec990e7a3f271396c6d511e64aa":[1,0,7,3],
 "classCGAL_1_1Apollonius__site__2.html#abe606e3144b79178222c6be6f7aad71d":[1,0,7,4],
-"examples.html":[6],
+"examples.html":[4],
 "group__PkgApolloniusGraph2Concepts.html":[1,0,0],
 "group__PkgApolloniusGraph2Ref.html":[1,0],
-"hasModels.html":[3],
-"index.html":[0],
 "index.html":[],
+"index.html":[0],
 "index.html#Apollonius_graph_2FirstExample":[0,4,0],
 "index.html#Apollonius_graph_2FourthExample":[0,4,3],
 "index.html#Apollonius_graph_2SecondExample":[0,4,1],
@@ -230,8 +229,6 @@ var NAVTREEINDEX0 =
 "index.html#secapollonius2examples":[0,4],
 "index.html#secapollonius2hierarchy":[0,3],
 "index.html#secapollonius2traits":[0,2],
-"models.html":[2],
 "modules.html":[1],
-"namespaceCGAL.html":[5,0],
 "pages.html":[]
 };
