@@ -9,6 +9,6 @@ var group__PkgBGLIOFct =
     [ "WRL I/O Functions", "group__PkgBGLIoFuncsWRL.html", "group__PkgBGLIoFuncsWRL" ],
     [ "3MF I/O Functions", "group__PkgBGLIoFuncs3MF.html", "group__PkgBGLIoFuncs3MF" ],
     [ "I/O Functions (Deprecated)", "group__PkgBGLIOFctDeprecated.html", "group__PkgBGLIOFctDeprecated" ],
-    [ "read_polygon_mesh", "group__PkgBGLIOFct.html#ga49f5b5e6fbfcbfaaac7604c88e10915c", null ],
-    [ "write_polygon_mesh", "group__PkgBGLIOFct.html#gafa143949a33371dc6df8307be1ab8a66", null ]
+    [ "CGAL::IO::read_polygon_mesh", "group__PkgBGLIOFct.html#ga49f5b5e6fbfcbfaaac7604c88e10915c", null ],
+    [ "CGAL::IO::write_polygon_mesh", "group__PkgBGLIOFct.html#gafa143949a33371dc6df8307be1ab8a66", null ]
 ];
\ No newline at end of file
