@@ -24,7 +24,7 @@
 */
 var NAVTREE =
 [
-  [ "CGAL 6.0 - Intersecting Sequences of dD Iso-oriented Boxes", "index.html", [
+  [ "CGAL 6.0.1 - Intersecting Sequences of dD Iso-oriented Boxes", "index.html", [
     [ "User Manual", "index.html", "index" ],
     [ "Reference Manual", "modules.html", "modules" ],
     [ "Bibliography", "citelist.html", null ],
