@@ -2,8 +2,8 @@ var classCGAL_1_1Random__points__in__ball__d =
 [
     [ "difference_type", "classCGAL_1_1Random__points__in__ball__d.html#a598b01d6c0b1b248c7a52135c7f7176c", null ],
     [ "iterator_category", "classCGAL_1_1Random__points__in__ball__d.html#a548cd69c25fb9cfe4c77b2c46068be93", null ],
+    [ "pointer", "classCGAL_1_1Random__points__in__ball__d.html#a73cfddf66097ad278bc9c34c471134c5", null ],
+    [ "reference", "classCGAL_1_1Random__points__in__ball__d.html#ac69c8c50314de24466137867a01f7f91", null ],
     [ "value_type", "classCGAL_1_1Random__points__in__ball__d.html#a1a96fc6388ab7b049364d4c2969b1637", null ],
-    [ "Random_points_in_ball_d", "classCGAL_1_1Random__points__in__ball__d.html#ab824d642d6b4b8d8b8e069b74f9743e4", null ],
-    [ "pointer", "classCGAL_1_1Random__points__in__ball__d.html#a2333edebe80a77a61d284a586065a81d", null ],
-    [ "reference", "classCGAL_1_1Random__points__in__ball__d.html#a2c25223042f57e65841ef283dd0008c6", null ]
+    [ "Random_points_in_ball_d", "classCGAL_1_1Random__points__in__ball__d.html#ab824d642d6b4b8d8b8e069b74f9743e4", null ]
 ];
\ No newline at end of file
