@@ -3,9 +3,9 @@ var structCGAL_1_1Random__points__in__triangle__mesh__3 =
     [ "difference_type", "structCGAL_1_1Random__points__in__triangle__mesh__3.html#af3762b1a17c904ad63940a5c749b24d0", null ],
     [ "iterator_category", "structCGAL_1_1Random__points__in__triangle__mesh__3.html#af84ae99633c878302f97706beba837a9", null ],
     [ "Point_3", "structCGAL_1_1Random__points__in__triangle__mesh__3.html#a2f38870f4d49e379f4de14e397cfc160", null ],
+    [ "pointer", "structCGAL_1_1Random__points__in__triangle__mesh__3.html#a6d2c7f0e3173f33101294cc4f48c67c7", null ],
+    [ "reference", "structCGAL_1_1Random__points__in__triangle__mesh__3.html#a3d544e711cd2be0737ec4e092b05e79c", null ],
     [ "value_type", "structCGAL_1_1Random__points__in__triangle__mesh__3.html#aaeb5c0ada0ca77f89dbe875cd5272280", null ],
     [ "Random_points_in_triangle_mesh_3", "structCGAL_1_1Random__points__in__triangle__mesh__3.html#a12e30de8a40d1c3dfba78d02ccadd16c", null ],
-    [ "Random_points_in_triangle_mesh_3", "structCGAL_1_1Random__points__in__triangle__mesh__3.html#a2e792d3e0b80811a2f00bfb6c57cc259", null ],
-    [ "pointer", "structCGAL_1_1Random__points__in__triangle__mesh__3.html#a3f61c644133966ba686246a02cc615f3", null ],
-    [ "reference", "structCGAL_1_1Random__points__in__triangle__mesh__3.html#a949112e39644ba44c9b12b9b19437256", null ]
+    [ "Random_points_in_triangle_mesh_3", "structCGAL_1_1Random__points__in__triangle__mesh__3.html#a2e792d3e0b80811a2f00bfb6c57cc259", null ]
 ];
\ No newline at end of file
