@@ -1,17 +1,17 @@
 var group__PkgHalfedgeDS__HDS =
 [
-    [ "HalfedgeDS_default", "classCGAL_1_1HalfedgeDS__default.html", [
+    [ "CGAL::HalfedgeDS_default< Traits, HalfedgeDSItems, Alloc >", "classCGAL_1_1HalfedgeDS__default.html", [
       [ "iterator_category", "classCGAL_1_1HalfedgeDS__default.html#a4c4874a7bc8e9bbd49cd1ee10f6eba6c", null ],
       [ "Supports_removal", "classCGAL_1_1HalfedgeDS__default.html#a405eef7411a492f1addea7a6e06d27c8", null ]
     ] ],
-    [ "HalfedgeDS_list", "classCGAL_1_1HalfedgeDS__list.html", [
+    [ "CGAL::HalfedgeDS_list< Traits, HalfedgeDSItems, Alloc >", "classCGAL_1_1HalfedgeDS__list.html", [
       [ "iterator_category", "classCGAL_1_1HalfedgeDS__list.html#a82101092b5483f8ad539bc0a4b0e6e1f", null ],
       [ "Supports_removal", "classCGAL_1_1HalfedgeDS__list.html#a417790d6e9a7a8edd62cf2050b1b2f55", null ],
       [ "faces_splice", "classCGAL_1_1HalfedgeDS__list.html#a655658325c32b2978b16baa85dc89ebf", null ],
       [ "halfedges_splice", "classCGAL_1_1HalfedgeDS__list.html#a6cc1bc218e3601a7c58575740a10acb4", null ],
       [ "vertices_splice", "classCGAL_1_1HalfedgeDS__list.html#a3ea6d8bcceefe628948b29aca2a87985", null ]
     ] ],
-    [ "HalfedgeDS_vector", "classCGAL_1_1HalfedgeDS__vector.html", [
+    [ "CGAL::HalfedgeDS_vector< Traits, HalfedgeDSItems, Alloc >", "classCGAL_1_1HalfedgeDS__vector.html", [
       [ "iterator_category", "classCGAL_1_1HalfedgeDS__vector.html#a5b409d4fdddaf5475a37a9dc113f6fc8", null ],
       [ "Supports_removal", "classCGAL_1_1HalfedgeDS__vector.html#a15c2a91792d75973e06860848563d168", null ]
     ] ]
