@@ -24,7 +24,7 @@
 */
 var NAVTREE =
 [
-  [ "CGAL 6.0 - Manual", "index.html", [
+  [ "CGAL 6.0.1 - Manual", "index.html", [
     [ "Getting Started with CGAL", "general_intro.html", "general_intro" ],
     [ "Tutorials", "tutorials.html", "tutorials" ],
     [ "Package Overview", "packages.html", [
