@@ -24,7 +24,7 @@
 */
 var NAVTREE =
 [
-  [ "CGAL 6.0 - 3D Mesh Generation", "index.html", [
+  [ "CGAL 6.0.1 - 3D Mesh Generation", "index.html", [
     [ "User Manual", "index.html", "index" ],
     [ "Reference Manual", "modules.html", "modules" ],
     [ "Deprecated List", "deprecated.html", null ],
@@ -37,7 +37,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "CGAL_2Mesh_3_2initialize_triangulation_from_gray_image_8h-example.html",
-"classMeshFacetCriteria__3.html#a4803ff8052db2aa5595a43b7ef64e136"
+"classMeshFacetCriteria__3.html#a3b321e484d4d952e30564e3045ce4baa"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
