@@ -1,39 +1,40 @@
 var NAVTREEINDEX0 =
 {
-"CGAL_2Mesh_3_2initialize_triangulation_from_gray_image_8h-example.html":[5,9],
-"CGAL_2Mesh_3_2initialize_triangulation_from_labeled_image_8h-example.html":[5,10],
+"CGAL_2Mesh_3_2initialize_triangulation_from_gray_image_8h-example.html":[5,10],
+"CGAL_2Mesh_3_2initialize_triangulation_from_labeled_image_8h-example.html":[5,11],
 "Mesh_3_2implicit_functions_8cpp-example.html":[5,0],
-"Mesh_3_2mesh_3D_gray_image_8cpp-example.html":[5,32],
+"Mesh_3_2mesh_3D_gray_image_8cpp-example.html":[5,33],
 "Mesh_3_2mesh_3D_gray_image_with_custom_initialization_8cpp-example.html":[5,2],
-"Mesh_3_2mesh_3D_gray_vtk_image_8cpp-example.html":[5,33],
+"Mesh_3_2mesh_3D_gray_vtk_image_8cpp-example.html":[5,34],
 "Mesh_3_2mesh_3D_image_8cpp-example.html":[5,1],
-"Mesh_3_2mesh_3D_image_variable_size_8cpp-example.html":[5,11],
+"Mesh_3_2mesh_3D_image_variable_size_8cpp-example.html":[5,12],
 "Mesh_3_2mesh_3D_image_with_custom_initialization_8cpp-example.html":[5,4],
 "Mesh_3_2mesh_3D_image_with_detection_of_features_8cpp-example.html":[5,5],
 "Mesh_3_2mesh_3D_image_with_features_8cpp-example.html":[5,3],
 "Mesh_3_2mesh_3D_image_with_input_features_8cpp-example.html":[5,6],
 "Mesh_3_2mesh_3D_weighted_image_8cpp-example.html":[5,7],
-"Mesh_3_2mesh_hybrid_mesh_domain_8cpp-example.html":[5,12],
-"Mesh_3_2mesh_implicit_domains_2_8cpp-example.html":[5,14],
-"Mesh_3_2mesh_implicit_domains_8cpp-example.html":[5,13],
-"Mesh_3_2mesh_implicit_ellipsoid_8cpp-example.html":[5,15],
-"Mesh_3_2mesh_implicit_sphere_8cpp-example.html":[5,16],
-"Mesh_3_2mesh_implicit_sphere_variable_size_8cpp-example.html":[5,17],
-"Mesh_3_2mesh_optimization_example_8cpp-example.html":[5,18],
-"Mesh_3_2mesh_optimization_lloyd_example_8cpp-example.html":[5,19],
-"Mesh_3_2mesh_polyhedral_complex_8cpp-example.html":[5,22],
-"Mesh_3_2mesh_polyhedral_complex_sm_8cpp-example.html":[5,23],
-"Mesh_3_2mesh_polyhedral_domain_8cpp-example.html":[5,20],
-"Mesh_3_2mesh_polyhedral_domain_sm_8cpp-example.html":[5,21],
-"Mesh_3_2mesh_polyhedral_domain_with_edge_distance_8cpp-example.html":[5,26],
-"Mesh_3_2mesh_polyhedral_domain_with_features_8cpp-example.html":[5,25],
-"Mesh_3_2mesh_polyhedral_domain_with_features_sizing_8cpp-example.html":[5,28],
-"Mesh_3_2mesh_polyhedral_domain_with_features_sm_8cpp-example.html":[5,27],
-"Mesh_3_2mesh_polyhedral_domain_with_lipschitz_sizing_8cpp-example.html":[5,30],
-"Mesh_3_2mesh_polyhedral_domain_with_surface_inside_8cpp-example.html":[5,29],
-"Mesh_3_2mesh_two_implicit_spheres_with_balls_8cpp-example.html":[5,31],
-"Mesh_3_2random_labeled_image_8h-example.html":[5,8],
-"Mesh_3_2remesh_polyhedral_surface_8cpp-example.html":[5,24],
+"Mesh_3_2mesh_3D_weighted_image_with_detection_of_features_8cpp-example.html":[5,8],
+"Mesh_3_2mesh_hybrid_mesh_domain_8cpp-example.html":[5,13],
+"Mesh_3_2mesh_implicit_domains_2_8cpp-example.html":[5,15],
+"Mesh_3_2mesh_implicit_domains_8cpp-example.html":[5,14],
+"Mesh_3_2mesh_implicit_ellipsoid_8cpp-example.html":[5,16],
+"Mesh_3_2mesh_implicit_sphere_8cpp-example.html":[5,17],
+"Mesh_3_2mesh_implicit_sphere_variable_size_8cpp-example.html":[5,18],
+"Mesh_3_2mesh_optimization_example_8cpp-example.html":[5,19],
+"Mesh_3_2mesh_optimization_lloyd_example_8cpp-example.html":[5,20],
+"Mesh_3_2mesh_polyhedral_complex_8cpp-example.html":[5,23],
+"Mesh_3_2mesh_polyhedral_complex_sm_8cpp-example.html":[5,24],
+"Mesh_3_2mesh_polyhedral_domain_8cpp-example.html":[5,21],
+"Mesh_3_2mesh_polyhedral_domain_sm_8cpp-example.html":[5,22],
+"Mesh_3_2mesh_polyhedral_domain_with_edge_distance_8cpp-example.html":[5,27],
+"Mesh_3_2mesh_polyhedral_domain_with_features_8cpp-example.html":[5,26],
+"Mesh_3_2mesh_polyhedral_domain_with_features_sizing_8cpp-example.html":[5,29],
+"Mesh_3_2mesh_polyhedral_domain_with_features_sm_8cpp-example.html":[5,28],
+"Mesh_3_2mesh_polyhedral_domain_with_lipschitz_sizing_8cpp-example.html":[5,31],
+"Mesh_3_2mesh_polyhedral_domain_with_surface_inside_8cpp-example.html":[5,30],
+"Mesh_3_2mesh_two_implicit_spheres_with_balls_8cpp-example.html":[5,32],
+"Mesh_3_2random_labeled_image_8h-example.html":[5,9],
+"Mesh_3_2remesh_polyhedral_surface_8cpp-example.html":[5,25],
 "annotated.html":[4],
 "citelist.html":[3],
 "classBisectionGeometricTraits__3.html":[1,0,1,0],
@@ -248,6 +249,5 @@ var NAVTREEINDEX0 =
 "classMeshEdgeCriteria__3.html#abda226ec819332ac1a69a97f3759f1af":[1,0,0,5,3],
 "classMeshEdgeCriteria__3.html#ad6d0c00829f27332881a1164284d7408":[1,0,0,5,1],
 "classMeshFacetCriteria__3.html":[1,0,0,6],
-"classMeshFacetCriteria__3.html#a2f4c1a086e867ecaf8fbb2c4019be484":[1,0,0,6,5],
-"classMeshFacetCriteria__3.html#a3b321e484d4d952e30564e3045ce4baa":[1,0,0,6,4]
+"classMeshFacetCriteria__3.html#a2f4c1a086e867ecaf8fbb2c4019be484":[1,0,0,6,5]
 };
