@@ -1,7 +1,7 @@
 var examples =
 [
     [ "Nef_2/nef_2_construction.cpp", "Nef_2_2nef_2_construction_8cpp-example.html", null ],
-    [ "Nef_2/nef_2_exploration.cpp", "Nef_2_2nef_2_exploration_8cpp-example.html", null ],
     [ "Nef_2/nef_2_intersection.cpp", "Nef_2_2nef_2_intersection_8cpp-example.html", null ],
-    [ "Nef_2/nef_2_polylines.cpp", "Nef_2_2nef_2_polylines_8cpp-example.html", null ]
+    [ "Nef_2/nef_2_polylines.cpp", "Nef_2_2nef_2_polylines_8cpp-example.html", null ],
+    [ "Nef_2/nef_2_exploration.cpp", "Nef_2_2nef_2_exploration_8cpp-example.html", null ]
 ];
\ No newline at end of file
