@@ -1,52 +1,45 @@
 var NAVTREEINDEX0 =
 {
-"CORE__BigFloat_8h.html":[6,0,0],
-"CORE__BigInt_8h.html":[6,0,1],
-"CORE__BigRat_8h.html":[6,0,2],
-"CORE__Expr_8h.html":[6,0,3],
-"Exact__integer_8h.html":[6,1,0],
-"Exact__integer_8h.html#gae96d924c796bfc4e781d28f81df43c52":[6,1,0,0],
-"Exact__rational_8h.html":[6,1,1],
-"Exact__rational_8h.html#ga0849ff44771b19582218ebdfa5614f64":[6,1,1,0],
-"FPU_8h.html":[6,0,6],
-"Gmpfi_8h.html":[6,0,7],
-"Gmpfr_8h.html":[6,0,8],
-"Gmpq_8h.html":[6,0,9],
-"Gmpz_8h.html":[6,0,11],
-"Gmpzf_8h.html":[6,0,12],
-"Interval__nt_8h.html":[6,0,14],
-"Interval__nt_8h.html#ga2e3fce8233225177f57d66e7ed00880f":[6,0,14,0],
-"Lazy__exact__nt_8h.html":[6,0,15],
-"MP__Float_8h.html":[6,0,22],
-"Mpzf_8h.html":[6,0,23],
-"NT__converter_8h.html":[6,0,24],
-"Number__type__checker_8h.html":[6,0,25],
-"Quotient_8h.html":[6,0,27],
-"Rational__traits_8h.html":[6,0,28],
-"RootOf__2_8h.html":[6,2,0],
-"Root__of__traits_8h.html":[6,0,29],
-"Root__of__traits_8h.html#ga4cb90aeebfe5ff7cf7eef83ae2f09918":[6,0,29,1],
-"Root__of__traits_8h.html#ga65dbf48e30821c7445bc50480e3c5242":[6,0,29,3],
-"Root__of__traits_8h.html#ga7b3b3eb35124b0c46373c88e324a7a95":[6,0,29,0],
-"Root__of__traits_8h.html#ga9f5fc25b40d694cc581931db4a1f8245":[6,0,29,2],
-"Sqrt__extension_8h.html":[6,0,31],
-"annotated.html":[5],
-"citelist.html":[4],
+"CORE__BigFloat_8h.html":[4,0,0],
+"CORE__BigInt_8h.html":[4,0,1],
+"CORE__BigRat_8h.html":[4,0,2],
+"CORE__Expr_8h.html":[4,0,3],
+"Exact__integer_8h.html":[4,1,0],
+"Exact__rational_8h.html":[4,1,1],
+"FPU_8h.html":[4,0,6],
+"Gmpfi_8h.html":[4,0,7],
+"Gmpfr_8h.html":[4,0,8],
+"Gmpq_8h.html":[4,0,9],
+"Gmpz_8h.html":[4,0,11],
+"Gmpzf_8h.html":[4,0,12],
+"Interval__nt_8h.html":[4,0,14],
+"Lazy__exact__nt_8h.html":[4,0,15],
+"MP__Float_8h.html":[4,0,22],
+"Mpzf_8h.html":[4,0,23],
+"NT__converter_8h.html":[4,0,24],
+"Number__type__checker_8h.html":[4,0,25],
+"Quotient_8h.html":[4,0,27],
+"Rational__traits_8h.html":[4,0,28],
+"RootOf__2_8h.html":[4,2,0],
+"Root__of__traits_8h.html":[4,0,29],
+"Sqrt__extension_8h.html":[4,0,31],
+"annotated.html":[3],
+"citelist.html":[2],
 "classCGAL_1_1Gmpfi.html":[1,0,4,0],
 "classCGAL_1_1Gmpfi.html#a0be0ac160a6efb221bb84417eca1f2fd":[1,0,4,0,26],
-"classCGAL_1_1Gmpfi.html#a0efd1136937040ce353b9f5cf0c0be45":[1,0,4,0,7],
-"classCGAL_1_1Gmpfi.html#a1484e0b8b7ae7145408cd22b668f9950":[1,0,4,0,18],
 "classCGAL_1_1Gmpfi.html#a1db542610ba45db7bf8382617e64f3c9":[1,0,4,0,5],
 "classCGAL_1_1Gmpfi.html#a1db94077a2e5e0e1658f8f93bc96a9f7":[1,0,4,0,15],
-"classCGAL_1_1Gmpfi.html#a2049fe5677026522611d63f239d27979":[1,0,4,0,29],
 "classCGAL_1_1Gmpfi.html#a253b29b3b7fde95e91f0e8137cf6c79b":[1,0,4,0,9],
+"classCGAL_1_1Gmpfi.html#a2740549d928ef5e53c842e386e032157":[1,0,4,0,18],
 "classCGAL_1_1Gmpfi.html#a2a2512b668b1e18552466721cd067f36":[1,0,4,0,4],
 "classCGAL_1_1Gmpfi.html#a2c4a745e20b35ee4d737fd1d6695adbe":[1,0,4,0,21],
-"classCGAL_1_1Gmpfi.html#a2cc8f04efe3d32471467525d0c6aaee8":[1,0,4,0,20],
 "classCGAL_1_1Gmpfi.html#a2d6303f2e1044ce369211a6dfbb47e01":[1,0,4,0,10],
-"classCGAL_1_1Gmpfi.html#a315944de26eb866cd7904c45fc327093":[1,0,4,0,30],
+"classCGAL_1_1Gmpfi.html#a3b3d990d1a3c4d0e650602891568bb6b":[1,0,4,0,24],
+"classCGAL_1_1Gmpfi.html#a3c583a79cab5c32ecbcb9ca758b265fe":[1,0,4,0,20],
 "classCGAL_1_1Gmpfi.html#a521a081a49c24894b2da25bda4cc31df":[1,0,4,0,2],
-"classCGAL_1_1Gmpfi.html#a6f8491a198cc66fc3cddaf6c920e072e":[1,0,4,0,16],
+"classCGAL_1_1Gmpfi.html#a54464fe5588cfb18cc95964238c39255":[1,0,4,0,29],
+"classCGAL_1_1Gmpfi.html#a6e369e37d2dca1559f80bc94575697c5":[1,0,4,0,14],
+"classCGAL_1_1Gmpfi.html#a7696967955bf5c424a405e3ba4ea6826":[1,0,4,0,30],
 "classCGAL_1_1Gmpfi.html#a7be97caf5f6e811a84c79b3371eaec95":[1,0,4,0,27],
 "classCGAL_1_1Gmpfi.html#a7e7113f954d2ea3f50a12f82bdb9e928":[1,0,4,0,13],
 "classCGAL_1_1Gmpfi.html#a8d4592d4da994f82fb2383888298d451":[1,0,4,0,3],
@@ -54,50 +47,50 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Gmpfi.html#a9add3037319cf7a041c2536b13dbf313":[1,0,4,0,12],
 "classCGAL_1_1Gmpfi.html#a9f8a4340e4779822d912c30078af18a1":[1,0,4,0,23],
 "classCGAL_1_1Gmpfi.html#aa27c7abb10d750611fffd948e75d606e":[1,0,4,0,0],
-"classCGAL_1_1Gmpfi.html#aa6ec103d5dc4771f121bb41d18702b4f":[1,0,4,0,28],
 "classCGAL_1_1Gmpfi.html#aaea7c3eaae09c960f6e275038e18a8fe":[1,0,4,0,22],
 "classCGAL_1_1Gmpfi.html#aaf451c04ecae1055c7598b1708a6b6ae":[1,0,4,0,19],
-"classCGAL_1_1Gmpfi.html#acae4097902125e0bf56780d4645446f3":[1,0,4,0,24],
+"classCGAL_1_1Gmpfi.html#ab490171fed04b0ff4ccd155850c8fa25":[1,0,4,0,16],
+"classCGAL_1_1Gmpfi.html#abe6805a3d5615531663c23abdb6042c0":[1,0,4,0,7],
 "classCGAL_1_1Gmpfi.html#ad5aa9afe0c587061400f0fd8ffe4335f":[1,0,4,0,32],
 "classCGAL_1_1Gmpfi.html#ada374a446232b6163ba62dc8c7e4349b":[1,0,4,0,11],
 "classCGAL_1_1Gmpfi.html#adc4e5603c4092c4e9a4c64d81acc9574":[1,0,4,0,6],
 "classCGAL_1_1Gmpfi.html#aec6c04fb4252bedfae9b651f186b4fde":[1,0,4,0,31],
 "classCGAL_1_1Gmpfi.html#af2f101c60d04a4d84133c2f58819e69d":[1,0,4,0,17],
 "classCGAL_1_1Gmpfi.html#af5dc1cde74e5e9ebf2fec2bb8c917048":[1,0,4,0,25],
+"classCGAL_1_1Gmpfi.html#af7696e92b65959f4e3898cb33a32e67f":[1,0,4,0,28],
 "classCGAL_1_1Gmpfi.html#af89061521e58034ea54a975b2adfae15":[1,0,4,0,8],
-"classCGAL_1_1Gmpfi.html#af9dfe4becbedcbf51e8281235bb96724":[1,0,4,0,14],
 "classCGAL_1_1Gmpfr.html":[1,0,4,1],
 "classCGAL_1_1Gmpfr.html#a0008c5140f71dc9ba2de516ea4a92c2a":[1,0,4,1,16],
 "classCGAL_1_1Gmpfr.html#a0872bdb4d6cf7523aba5049fe273f5f3":[1,0,4,1,12],
+"classCGAL_1_1Gmpfr.html#a0a2939a8656e57b57ad509a9bdbf5ea9":[1,0,4,1,41],
 "classCGAL_1_1Gmpfr.html#a0a9761e738fc5458e55de4c0f882a035":[1,0,4,1,25],
 "classCGAL_1_1Gmpfr.html#a191b8ac25cca42883c14a20ab6c03a4b":[1,0,4,1,38],
-"classCGAL_1_1Gmpfr.html#a1988f03583a6df5072e5da4ab07032c9":[1,0,4,1,39],
 "classCGAL_1_1Gmpfr.html#a1b3d6c5968d6c785ea3f419cbe9e84d8":[1,0,4,1,31],
 "classCGAL_1_1Gmpfr.html#a1db92367376568082364fc908ea14f44":[1,0,4,1,34],
 "classCGAL_1_1Gmpfr.html#a1f1cb0588fdd8c31905a72ca5f357043":[1,0,4,1,22],
 "classCGAL_1_1Gmpfr.html#a23a2f64830eb75abf75bb41a02767f81":[1,0,4,1,17],
 "classCGAL_1_1Gmpfr.html#a240e82d50dc9ef4c23ea96eafb1b48b0":[1,0,4,1,6],
 "classCGAL_1_1Gmpfr.html#a24bfd650378aaa2dfa75ecfad1ed1127":[1,0,4,1,32],
+"classCGAL_1_1Gmpfr.html#a254a0adbc3a76c3fed9d259c2bcc191a":[1,0,4,1,42],
 "classCGAL_1_1Gmpfr.html#a2eb8ce38937e00577ee21892e11938d5":[1,0,4,1,33],
 "classCGAL_1_1Gmpfr.html#a30e3829896913178f2c984a94b3f535a":[1,0,4,1,9],
 "classCGAL_1_1Gmpfr.html#a33dfd070f209161b0dba7bf9d4412de5":[1,0,4,1,24],
 "classCGAL_1_1Gmpfr.html#a36b154cb7b0c8f3cb4e01ba5c7ed5a3b":[1,0,4,1,20],
+"classCGAL_1_1Gmpfr.html#a3c80cbdcbbaa4d63d9449bc6e86d34e3":[1,0,4,1,40],
 "classCGAL_1_1Gmpfr.html#a3e417372222484e098796b7a504966d3":[1,0,4,1,8],
-"classCGAL_1_1Gmpfr.html#a3f92a971d6aa25808a92e13f56ae82a0":[1,0,4,1,40],
 "classCGAL_1_1Gmpfr.html#a4239e1d748eaed7b7534acd498aedc41":[1,0,4,1,11],
 "classCGAL_1_1Gmpfr.html#a45b23f4a7f5a8b096efd03a877341464":[1,0,4,1,18],
 "classCGAL_1_1Gmpfr.html#a45f3ce6a9087b34549b1ee7c95571329":[1,0,4,1,0],
+"classCGAL_1_1Gmpfr.html#a49a1426aaf175cf33fd4f48a47af3f5a":[1,0,4,1,39],
 "classCGAL_1_1Gmpfr.html#a50cc335aa064eec725e2f7fdd26c2bb7":[1,0,4,1,26],
 "classCGAL_1_1Gmpfr.html#a50cde0e62839992e8e39b3cf3ccf6708":[1,0,4,1,30],
 "classCGAL_1_1Gmpfr.html#a573ceaded2ff06810798cac00e7537f9":[1,0,4,1,28],
 "classCGAL_1_1Gmpfr.html#a584a82909607aa2a238a905b3c1546e7":[1,0,4,1,45],
-"classCGAL_1_1Gmpfr.html#a5cbf3bcc3b93df9f4a9c080e13649aef":[1,0,4,1,15],
-"classCGAL_1_1Gmpfr.html#a5d0ea5544c44a90e1422a201d8530300":[1,0,4,1,14],
+"classCGAL_1_1Gmpfr.html#a5cbf3bcc3b93df9f4a9c080e13649aef":[1,0,4,1,14],
+"classCGAL_1_1Gmpfr.html#a5d0ea5544c44a90e1422a201d8530300":[1,0,4,1,13],
 "classCGAL_1_1Gmpfr.html#a5ec96fcc167aaa93c4561432173cfef6":[1,0,4,1,43],
 "classCGAL_1_1Gmpfr.html#a6492552d338d431c6f9e79d04a3c544b":[1,0,4,1,4],
-"classCGAL_1_1Gmpfr.html#a66f43c2f7dff43f9c576377bd82cbef4":[1,0,4,1,42],
 "classCGAL_1_1Gmpfr.html#a6ab4d80d5929857e065241a8f2117824":[1,0,4,1,1],
-"classCGAL_1_1Gmpfr.html#a6cff0f63981228f5bd1439a5c6694e89":[1,0,4,1,41],
 "classCGAL_1_1Gmpfr.html#a7778dc25c4b0979eb6fc88df80fe07d1":[1,0,4,1,37],
 "classCGAL_1_1Gmpfr.html#a81151e767cf96782336fa56edf5c1069":[1,0,4,1,35],
 "classCGAL_1_1Gmpfr.html#a8538f174ad8b5e3f5124cae66b08a69e":[1,0,4,1,10],
@@ -111,7 +104,7 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Gmpfr.html#adf6ddf48116f345eda58cd541ea5665a":[1,0,4,1,2],
 "classCGAL_1_1Gmpfr.html#ae6e1e74fbf90a5856d285afa69789a81":[1,0,4,1,21],
 "classCGAL_1_1Gmpfr.html#af2fd0abeb6902c9f500a0eedf9f801a1":[1,0,4,1,44],
-"classCGAL_1_1Gmpfr.html#af8cec21514fbe0c8af802f5eb55930d1":[1,0,4,1,13],
+"classCGAL_1_1Gmpfr.html#af8cec21514fbe0c8af802f5eb55930d1":[1,0,4,1,15],
 "classCGAL_1_1Gmpfr.html#afcb23b9a0133c5af7a2796549e882410":[1,0,4,1,29],
 "classCGAL_1_1Gmpq.html":[1,0,4,2],
 "classCGAL_1_1Gmpq.html#a05838b4d5098b6a466bea2c53e053e06":[1,0,4,2,3],
@@ -130,30 +123,30 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Gmpq.html#af500a1e857b804dd277684481b768502":[1,0,4,2,9],
 "classCGAL_1_1Gmpq.html#af5420621617bb5b9990f6e5c0d43d9e9":[1,0,4,2,14],
 "classCGAL_1_1Gmpz.html":[1,0,4,5],
-"classCGAL_1_1Gmpz.html#a07c6c253ac8e92c2a8cbb76a6ab0551d":[1,0,4,5,8],
-"classCGAL_1_1Gmpz.html#a0c250202910a1b59a02a9e95b17ff22c":[1,0,4,5,11],
-"classCGAL_1_1Gmpz.html#a132bbd362c99404122a166a0da644a37":[1,0,4,5,12],
+"classCGAL_1_1Gmpz.html#a136d2ef45489ad4f19816feb728f634e":[1,0,4,5,11],
 "classCGAL_1_1Gmpz.html#a195cab46a559f7faad9d11dde74039f9":[1,0,4,5,14],
-"classCGAL_1_1Gmpz.html#a1c931cee006b304cb2daa91f1028fb46":[1,0,4,5,10],
+"classCGAL_1_1Gmpz.html#a2f06fb3c9aad7eeafacb1c6f14201aaf":[1,0,4,5,6],
 "classCGAL_1_1Gmpz.html#a3288535745329a40cdca5a400b7272f4":[1,0,4,5,1],
 "classCGAL_1_1Gmpz.html#a328d7d3799767ae0492e3c35cfdbb21c":[1,0,4,5,22],
+"classCGAL_1_1Gmpz.html#a3665f7134836f02727c63d8f83dbf6e6":[1,0,4,5,8],
 "classCGAL_1_1Gmpz.html#a3fabf0477fa857ae951124cf042cab8a":[1,0,4,5,3],
 "classCGAL_1_1Gmpz.html#a45866af07ae72eb256d53941bdab41ef":[1,0,4,5,0],
+"classCGAL_1_1Gmpz.html#a4a4759af65ad91f95d31dfab8abcebbe":[1,0,4,5,10],
 "classCGAL_1_1Gmpz.html#a62fd56c5a15d08169ba1ab6c0714c21b":[1,0,4,5,16],
-"classCGAL_1_1Gmpz.html#a6775654be96bd0fa784e2b6c72286dd3":[1,0,4,5,17],
 "classCGAL_1_1Gmpz.html#a684cac8c390b166265ea6fe17e74594a":[1,0,4,5,21],
+"classCGAL_1_1Gmpz.html#a82c0b52f5fdd64e6b477a4ed6744caf2":[1,0,4,5,12],
 "classCGAL_1_1Gmpz.html#a9c4b2a792a28f255257265711e29528f":[1,0,4,5,2],
 "classCGAL_1_1Gmpz.html#a9ecfd8e9405b1821114c32080de06359":[1,0,4,5,4],
+"classCGAL_1_1Gmpz.html#aa154fe8f077cb96c81755d537d5ed13c":[1,0,4,5,17],
 "classCGAL_1_1Gmpz.html#aa268ab14b3f37e4aa95f41af2573a4a1":[1,0,4,5,20],
 "classCGAL_1_1Gmpz.html#aaddaa7b373de90630a08bb60ba909c5c":[1,0,4,5,15],
 "classCGAL_1_1Gmpz.html#ab0d581e5a0442ea2f7390e2646808068":[1,0,4,5,23],
 "classCGAL_1_1Gmpz.html#ab88e368511e4ee2c0c8ff20478a13a89":[1,0,4,5,9],
 "classCGAL_1_1Gmpz.html#abaeb01aee77dcd70a1ae263d8d6c3cd0":[1,0,4,5,7],
+"classCGAL_1_1Gmpz.html#abc96a92ad4f9eb410fa2725df3b73521":[1,0,4,5,13],
 "classCGAL_1_1Gmpz.html#abe0569efb3f91f49f606971950df0216":[1,0,4,5,19],
 "classCGAL_1_1Gmpz.html#ac6408e7b3925e253ac45782fde3cdd26":[1,0,4,5,18],
-"classCGAL_1_1Gmpz.html#acc68022a704269709e22d2035a920228":[1,0,4,5,13],
-"classCGAL_1_1Gmpz.html#ae06e8d6dd965635301aa693fe48e90be":[1,0,4,5,5],
-"classCGAL_1_1Gmpz.html#af1cf1ec361179c9019e679d128e3f1f4":[1,0,4,5,6],
+"classCGAL_1_1Gmpz.html#ad3acfd44fffdfa858790255828c6c103":[1,0,4,5,5],
 "classCGAL_1_1Gmpzf.html":[1,0,4,6],
 "classCGAL_1_1Gmpzf.html#a53918ddff3baee9d3a4e8f7b3047eef1":[1,0,4,6,1],
 "classCGAL_1_1Gmpzf.html#a580e95e0e5b31860b85d6e0d2d2e59ea":[1,0,4,6,0],
@@ -195,11 +188,11 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Is__valid.html":[1,0,8,3],
 "classCGAL_1_1Is__valid.html#af3e6bbf53998cd5689cc047ec83e1887":[1,0,8,3,0],
 "classCGAL_1_1Lazy__exact__nt.html":[1,0,5,1],
-"classCGAL_1_1Lazy__exact__nt.html#a08f861319642a3e1614e2afe9df1bab7":[1,0,5,1,7],
+"classCGAL_1_1Lazy__exact__nt.html#a06a5e6820cac40cecbcc3fb1f9ef330a":[1,0,5,1,7],
+"classCGAL_1_1Lazy__exact__nt.html#a1034c6e18f2896195feaf5d46f05ce19":[1,0,5,1,4],
 "classCGAL_1_1Lazy__exact__nt.html#a14bf3ceb6a967a2d0ab6ee0f9b91dfc0":[1,0,5,1,1],
 "classCGAL_1_1Lazy__exact__nt.html#a1b1e71678b9cb5dcfbca923e6abb0959":[1,0,5,1,5],
 "classCGAL_1_1Lazy__exact__nt.html#a2341c2358a9c1f61ff433519f927f5b6":[1,0,5,1,9],
-"classCGAL_1_1Lazy__exact__nt.html#a6a9e7b80a3e400d647a4d24943afc8ed":[1,0,5,1,4],
 "classCGAL_1_1Lazy__exact__nt.html#a80ce2b0a50c9ce34822d2d62b48a9c5f":[1,0,5,1,0],
 "classCGAL_1_1Lazy__exact__nt.html#a84c7e08fb0073f43782804d39aea3ca6":[1,0,5,1,10],
 "classCGAL_1_1Lazy__exact__nt.html#a87c2ac9c606ee86bf4953899dbd27829":[1,0,5,1,2],
@@ -219,13 +212,13 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1MP__Float.html#af73ef0f40de89faebb93df57fd7c84a7":[1,0,5,2,5],
 "classCGAL_1_1Number__type__checker.html":[1,0,5,3],
 "classCGAL_1_1Number__type__checker.html#a09b038a5e5049be838cd156e1982f473":[1,0,5,3,3],
+"classCGAL_1_1Number__type__checker.html#a15222bd8aa6dd03ada7fc850cb932baa":[1,0,5,3,6],
 "classCGAL_1_1Number__type__checker.html#a1567968e948e0d0455be6a1026e916b2":[1,0,5,3,10],
 "classCGAL_1_1Number__type__checker.html#a37d7b5e6c3741620519fa562c81c7b55":[1,0,5,3,2],
-"classCGAL_1_1Number__type__checker.html#a548ec7dc85cee64e93a8ad83edc32e6a":[1,0,5,3,5],
+"classCGAL_1_1Number__type__checker.html#a5aa8d43c85e46bdce5f0893d939cb16d":[1,0,5,3,7],
 "classCGAL_1_1Number__type__checker.html#a8137867bd6e94a2c013e83e4d72c219d":[1,0,5,3,4],
-"classCGAL_1_1Number__type__checker.html#a90e6268a7d65de471039e67f058fcefe":[1,0,5,3,7],
-"classCGAL_1_1Number__type__checker.html#a9d4e39e7808c1d9be85a6368dc830b58":[1,0,5,3,6],
-"classCGAL_1_1Number__type__checker.html#ab9a8dd82ee07ce601d5aaafb211006b1":[1,0,5,3,8],
+"classCGAL_1_1Number__type__checker.html#a8ca5b6299358103335fa4f446e7be99e":[1,0,5,3,5],
+"classCGAL_1_1Number__type__checker.html#abb54baf522a66192729a007eb99fae7b":[1,0,5,3,8],
 "classCGAL_1_1Number__type__checker.html#ad56077208ddb8fa4429602dbf59a4222":[1,0,5,3,1],
 "classCGAL_1_1Number__type__checker.html#adbd76b1e89df120d6309dfb0d30ce77f":[1,0,5,3,0],
 "classCGAL_1_1Number__type__checker.html#aefd7499eb58d63920df8bc78799f71f4":[1,0,5,3,9],
@@ -246,8 +239,15 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Rational__traits.html#a182c967765055c50b473ebd9ecaf4c13":[1,0,6,0,4],
 "classCGAL_1_1Rational__traits.html#a4fc33a9ace726befaf39f07fc2d19375":[1,0,6,0,6],
 "classCGAL_1_1Rational__traits.html#a61f43e34a39b92bb04237721272987fd":[1,0,6,0,1],
-"classCGAL_1_1Rational__traits.html#ac3f0ef292e9ea9c44afd762c0f0072f0":[1,0,6,0,3],
-"classCGAL_1_1Rational__traits.html#ac9948947523f60516288944a37a85556":[1,0,6,0,2],
+"classCGAL_1_1Rational__traits.html#ac3f0ef292e9ea9c44afd762c0f0072f0":[1,0,6,0,5],
+"classCGAL_1_1Rational__traits.html#ac9948947523f60516288944a37a85556":[1,0,6,0,3],
 "classCGAL_1_1Rational__traits.html#ade08a9f051b95ed2de96da69a90377c3":[1,0,6,0,0],
-"classCGAL_1_1Rational__traits.html#ae778b46cc2e91f3765e83b4a6002e661":[1,0,6,0,5]
+"classCGAL_1_1Rational__traits.html#ae778b46cc2e91f3765e83b4a6002e661":[1,0,6,0,2],
+"classCGAL_1_1Set__ieee__double__precision.html":[1,0,8,1],
+"classCGAL_1_1Set__ieee__double__precision.html#a1ff28f78034e2a2c61ee53183b3d4a7c":[1,0,8,1,0],
+"classCGAL_1_1Set__ieee__double__precision.html#a2203d4c1f70c2454c6bbe5888d3f23a1":[1,0,8,1,1],
+"classCGAL_1_1Set__ieee__double__precision.html#a4a328d0ca2892ada2b64ae5aca2fcc95":[1,0,8,1,2],
+"classCGAL_1_1Sqrt__extension.html":[1,0,7,1],
+"classCGAL_1_1Sqrt__extension.html#a002c752b26809bf0bfe56528dbb34e3d":[1,0,7,1,13],
+"classCGAL_1_1Sqrt__extension.html#a2679732b1ccfe999885b933641d30d15":[1,0,7,1,5]
 };
