@@ -47,5 +47,6 @@ var examples =
     [ "Polygon_mesh_processing/remesh_planar_patches.cpp", "Polygon_mesh_processing_2remesh_planar_patches_8cpp-example.html", null ],
     [ "Polygon_mesh_processing/remesh_almost_planar_patches.cpp", "Polygon_mesh_processing_2remesh_almost_planar_patches_8cpp-example.html", null ],
     [ "Polygon_mesh_processing/sample_example.cpp", "Polygon_mesh_processing_2sample_example_8cpp-example.html", null ],
-    [ "Polygon_mesh_processing/soup_autorefinement.cpp", "Polygon_mesh_processing_2soup_autorefinement_8cpp-example.html", null ]
+    [ "Polygon_mesh_processing/soup_autorefinement.cpp", "Polygon_mesh_processing_2soup_autorefinement_8cpp-example.html", null ],
+    [ "Polygon_mesh_processing/isotropic_remeshing_with_allow_move.cpp", "Polygon_mesh_processing_2isotropic_remeshing_with_allow_move_8cpp-example.html", null ]
 ];
\ No newline at end of file
