@@ -24,7 +24,7 @@
 */
 var NAVTREE =
 [
-  [ "CGAL 6.0 - Polygon Mesh Processing", "index.html", [
+  [ "CGAL 6.0.1 - Polygon Mesh Processing", "index.html", [
     [ "User Manual", "index.html", "index" ],
     [ "Reference Manual", "modules.html", "modules" ],
     [ "Deprecated List", "deprecated.html", null ],
@@ -37,8 +37,8 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "Poisson_surface_reconstruction_3_2poisson_reconstruction_example_8cpp-example.html",
-"group__PMP__hole__filling__grp.html#ga3abdf2d0558822e85f060966b69cae98",
-"structCGAL_1_1Polyhedral__envelope.html#a891b808e7923aed227837b34f2e2f4dc"
+"group__PMP__hole__filling__grp.html#ga3294d97ef095a5ac3b52bc4f0c2c214c",
+"structCGAL_1_1Polyhedral__envelope.html#a81553453f9dbdbd5156c8b462262b29e"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
