@@ -24,6 +24,7 @@ var NAVTREEINDEX0 =
 "Polygon_mesh_processing_2interpolated_corrected_curvatures_SM_8cpp-example.html":[5,19],
 "Polygon_mesh_processing_2interpolated_corrected_curvatures_vertex_8cpp-example.html":[5,21],
 "Polygon_mesh_processing_2isotropic_remeshing_example_8cpp-example.html":[5,18],
+"Polygon_mesh_processing_2isotropic_remeshing_with_allow_move_8cpp-example.html":[5,48],
 "Polygon_mesh_processing_2locate_example_8cpp-example.html":[5,39],
 "Polygon_mesh_processing_2manifoldness_repair_example_8cpp-example.html":[5,34],
 "Polygon_mesh_processing_2mesh_slicer_example_8cpp-example.html":[5,17],
@@ -248,6 +249,5 @@ var NAVTREEINDEX0 =
 "group__PMP__geometric__repair__grp.html#ga571b1605486d5cec0f4474aae3fa1905":[1,0,10,2],
 "group__PMP__geometric__repair__grp.html#ga91c02ef57e638faf2622eae93e7a25e2":[1,0,10,3],
 "group__PMP__hole__filling__grp.html":[1,0,2],
-"group__PMP__hole__filling__grp.html#ga18eac756a8f8e5d5f73e645fd4e26cad":[1,0,2,7],
-"group__PMP__hole__filling__grp.html#ga3294d97ef095a5ac3b52bc4f0c2c214c":[1,0,2,5]
+"group__PMP__hole__filling__grp.html#ga18eac756a8f8e5d5f73e645fd4e26cad":[1,0,2,7]
 };
