@@ -2,10 +2,10 @@ var structCGAL_1_1Constant__property__map =
 [
     [ "category", "structCGAL_1_1Constant__property__map.html#ad5a39dac17b9e1cf0e2ca837148cd364", null ],
     [ "key_type", "structCGAL_1_1Constant__property__map.html#ac18c1a94845be27bbfc09ce77e0fc60d", null ],
+    [ "reference", "structCGAL_1_1Constant__property__map.html#a27d5fa444bb9de5903fbed56fda57162", null ],
     [ "value_type", "structCGAL_1_1Constant__property__map.html#a4020201b5162039459e654f7cd842fd2", null ],
     [ "Constant_property_map", "structCGAL_1_1Constant__property__map.html#a78e50f41d32ad98747fb991a83fa72ce", null ],
     [ "get", "structCGAL_1_1Constant__property__map.html#a3c8ccb52f31c0260a6ec4ac6307b6eda", null ],
     [ "put", "structCGAL_1_1Constant__property__map.html#ada1c538622b8cb129e5508ce0be2bd23", null ],
-    [ "default_value", "structCGAL_1_1Constant__property__map.html#a1937d704192949d8d5225cf238f882c8", null ],
-    [ "reference", "structCGAL_1_1Constant__property__map.html#a53fe4c6f6275e4934796a3a5748b3215", null ]
+    [ "default_value", "structCGAL_1_1Constant__property__map.html#a1937d704192949d8d5225cf238f882c8", null ]
 ];
\ No newline at end of file
