@@ -1,7 +1,7 @@
 var group__PkgSegmentDelaunayGraph2Ref =
 [
     [ "Concepts", "group__PkgSegmentDelaunayGraph2Concepts.html", "group__PkgSegmentDelaunayGraph2Concepts" ],
-    [ "Segment_Delaunay_graph_2", "classCGAL_1_1Segment__Delaunay__graph__2.html", [
+    [ "CGAL::Segment_Delaunay_graph_2< Gt, St, DS >", "classCGAL_1_1Segment__Delaunay__graph__2.html", [
       [ "All_edges_iterator", "classCGAL_1_1Segment__Delaunay__graph__2.html#a3cb65e75134b2279d0f31440d6c4825f", null ],
       [ "All_faces_iterator", "classCGAL_1_1Segment__Delaunay__graph__2.html#ac49511156f955fc742814c228e037eca", null ],
       [ "All_vertices_iterator", "classCGAL_1_1Segment__Delaunay__graph__2.html#a9483678cb338f7f6cd653e080e04fbd9", null ],
@@ -37,14 +37,14 @@ var group__PkgSegmentDelaunayGraph2Ref =
       [ "all_vertices_begin", "classCGAL_1_1Segment__Delaunay__graph__2.html#a98a5678a7f3989208bcf797a9f19f70a", null ],
       [ "all_vertices_end", "classCGAL_1_1Segment__Delaunay__graph__2.html#a7e9e44d8f2de87613f4613d663a7ce8e", null ],
       [ "clear", "classCGAL_1_1Segment__Delaunay__graph__2.html#ad5602c6ee3823208254aeca3cfe6495b", null ],
-      [ "data_structure", "classCGAL_1_1Segment__Delaunay__graph__2.html#a5bceb12e920625d5698303e60f1c230f", null ],
+      [ "data_structure", "classCGAL_1_1Segment__Delaunay__graph__2.html#a3c5ab5beb60cc7c50ea4841e5108b087", null ],
       [ "dimension", "classCGAL_1_1Segment__Delaunay__graph__2.html#ace396a1db19375a56ab024daee16551c", null ],
-      [ "draw_dual", "classCGAL_1_1Segment__Delaunay__graph__2.html#a22eca07c01535722975450d1db60ce66", null ],
-      [ "draw_dual_edge", "classCGAL_1_1Segment__Delaunay__graph__2.html#a26e8261f8e9053298bfe547ad8946975", null ],
-      [ "draw_dual_edge", "classCGAL_1_1Segment__Delaunay__graph__2.html#a08ac5ca695d77b8210f5ef416797eec1", null ],
-      [ "draw_dual_edge", "classCGAL_1_1Segment__Delaunay__graph__2.html#af47108dfe92d0f41ea106bc36fc3f50a", null ],
-      [ "draw_dual_edge", "classCGAL_1_1Segment__Delaunay__graph__2.html#a6d076032dcbe826692c31518f88b6213", null ],
-      [ "draw_skeleton", "classCGAL_1_1Segment__Delaunay__graph__2.html#a09f3d4d9bc6da8b8305e1674cf2474ef", null ],
+      [ "draw_dual", "classCGAL_1_1Segment__Delaunay__graph__2.html#a5eb5a19db73870391d2a32ca3dd38e45", null ],
+      [ "draw_dual_edge", "classCGAL_1_1Segment__Delaunay__graph__2.html#afcc2a36040df3845d67e1d14a97563db", null ],
+      [ "draw_dual_edge", "classCGAL_1_1Segment__Delaunay__graph__2.html#a8facf6d405b3ed9ff076f73e4a7d21c1", null ],
+      [ "draw_dual_edge", "classCGAL_1_1Segment__Delaunay__graph__2.html#a86f340cf1f7b5d26e1f2f520f9d8a745", null ],
+      [ "draw_dual_edge", "classCGAL_1_1Segment__Delaunay__graph__2.html#a9b8ca967333ff8fa4d244038c16048c5", null ],
+      [ "draw_skeleton", "classCGAL_1_1Segment__Delaunay__graph__2.html#a453733666c46d66f87661df78febda65", null ],
       [ "file_input", "classCGAL_1_1Segment__Delaunay__graph__2.html#ac9d57105a6e48884fc75e484379d6738", null ],
       [ "file_output", "classCGAL_1_1Segment__Delaunay__graph__2.html#a7ba8284bef9be9d3f69dc4416de35de1", null ],
       [ "finite_edges_begin", "classCGAL_1_1Segment__Delaunay__graph__2.html#a2d1b5ff5235f6ee585a4cdffac2a71ba", null ],
@@ -54,7 +54,7 @@ var group__PkgSegmentDelaunayGraph2Ref =
       [ "finite_vertex", "classCGAL_1_1Segment__Delaunay__graph__2.html#a32a4f10cc2ccb876c82ac669fa80701e", null ],
       [ "finite_vertices_begin", "classCGAL_1_1Segment__Delaunay__graph__2.html#a9253b1d8e0294f6b9ba3b9dd9dd309ba", null ],
       [ "finite_vertices_end", "classCGAL_1_1Segment__Delaunay__graph__2.html#a0e30fb7490bb6f5794d7617ac50e59b3", null ],
-      [ "geom_traits", "classCGAL_1_1Segment__Delaunay__graph__2.html#ad032051767a15680ae9a8d553e704856", null ],
+      [ "geom_traits", "classCGAL_1_1Segment__Delaunay__graph__2.html#ac22960b106fdd0096dcc0b9f2038adb4", null ],
       [ "incident_edges", "classCGAL_1_1Segment__Delaunay__graph__2.html#aa30693cf070503b0f9c8fda2f2cade4c", null ],
       [ "incident_edges", "classCGAL_1_1Segment__Delaunay__graph__2.html#a4c916443215b0386f988f4822398161c", null ],
       [ "incident_faces", "classCGAL_1_1Segment__Delaunay__graph__2.html#a5e2930d0ae146011d7020dbbeebb98ec", null ],
@@ -65,23 +65,23 @@ var group__PkgSegmentDelaunayGraph2Ref =
       [ "infinite_vertex", "classCGAL_1_1Segment__Delaunay__graph__2.html#abc11b8fd15d62a3cc469c2dd907c1401", null ],
       [ "input_sites_begin", "classCGAL_1_1Segment__Delaunay__graph__2.html#ac99449fb3651fd2587bf2f8b59ab660f", null ],
       [ "input_sites_end", "classCGAL_1_1Segment__Delaunay__graph__2.html#a47cd3858386b0b2c85557e07856939dc", null ],
-      [ "insert", "classCGAL_1_1Segment__Delaunay__graph__2.html#accb50cf54c7c8dcc93e643a67fe81891", null ],
-      [ "insert", "classCGAL_1_1Segment__Delaunay__graph__2.html#a4c38d30277b965be645f8b3b11bba92d", null ],
-      [ "insert", "classCGAL_1_1Segment__Delaunay__graph__2.html#af95131302a9b3ae34940f1026658c177", null ],
       [ "insert", "classCGAL_1_1Segment__Delaunay__graph__2.html#a0e5ac3c19398daedfe871fdacd63b728", null ],
       [ "insert", "classCGAL_1_1Segment__Delaunay__graph__2.html#a5f787c033d11114a86ca3877b02c9033", null ],
       [ "insert", "classCGAL_1_1Segment__Delaunay__graph__2.html#ab092560ed8f6186ec7ed5e819366f9e4", null ],
       [ "insert", "classCGAL_1_1Segment__Delaunay__graph__2.html#a9be228deffb2ec2a3a799b33e4216b46", null ],
       [ "insert", "classCGAL_1_1Segment__Delaunay__graph__2.html#aa9ab750a38b8acbe5c0bf9b7ae5b5125", null ],
       [ "insert", "classCGAL_1_1Segment__Delaunay__graph__2.html#af0baf24d13f3c93f1e52a67599824406", null ],
+      [ "insert", "classCGAL_1_1Segment__Delaunay__graph__2.html#accb50cf54c7c8dcc93e643a67fe81891", null ],
+      [ "insert", "classCGAL_1_1Segment__Delaunay__graph__2.html#a4c38d30277b965be645f8b3b11bba92d", null ],
+      [ "insert", "classCGAL_1_1Segment__Delaunay__graph__2.html#af95131302a9b3ae34940f1026658c177", null ],
       [ "insert_points", "classCGAL_1_1Segment__Delaunay__graph__2.html#af34c5b5476782bfeab3065fd7cb843fd", null ],
-      [ "insert_segments", "classCGAL_1_1Segment__Delaunay__graph__2.html#aac42f0ea4bf167a0a09154acd6391cb1", null ],
       [ "insert_segments", "classCGAL_1_1Segment__Delaunay__graph__2.html#a21f1ac813bf15063da2c2ecbcdf30daa", null ],
-      [ "is_infinite", "classCGAL_1_1Segment__Delaunay__graph__2.html#ace15a75982eaf86f1c7d2507cf80a870", null ],
-      [ "is_infinite", "classCGAL_1_1Segment__Delaunay__graph__2.html#a47f6e41999c64bc3f915ddda91d6a669", null ],
-      [ "is_infinite", "classCGAL_1_1Segment__Delaunay__graph__2.html#a125ba2fc60742a07c85986ff73c2dc53", null ],
+      [ "insert_segments", "classCGAL_1_1Segment__Delaunay__graph__2.html#aac42f0ea4bf167a0a09154acd6391cb1", null ],
       [ "is_infinite", "classCGAL_1_1Segment__Delaunay__graph__2.html#ad3b42d6dc006c704c4759f820ff3226f", null ],
       [ "is_infinite", "classCGAL_1_1Segment__Delaunay__graph__2.html#a92e9bea4999d87150c894635e264b2f8", null ],
+      [ "is_infinite", "classCGAL_1_1Segment__Delaunay__graph__2.html#a47f6e41999c64bc3f915ddda91d6a669", null ],
+      [ "is_infinite", "classCGAL_1_1Segment__Delaunay__graph__2.html#a125ba2fc60742a07c85986ff73c2dc53", null ],
+      [ "is_infinite", "classCGAL_1_1Segment__Delaunay__graph__2.html#ace15a75982eaf86f1c7d2507cf80a870", null ],
       [ "is_valid", "classCGAL_1_1Segment__Delaunay__graph__2.html#a85fc80cedd5a0bf144d95f1ee38e482d", null ],
       [ "nearest_neighbor", "classCGAL_1_1Segment__Delaunay__graph__2.html#ab77199a11e58fa7af85c987e676aec59", null ],
       [ "nearest_neighbor", "classCGAL_1_1Segment__Delaunay__graph__2.html#a96b4599afe601a7ef4aa1f1e1c70df52", null ],
@@ -89,17 +89,17 @@ var group__PkgSegmentDelaunayGraph2Ref =
       [ "number_of_input_sites", "classCGAL_1_1Segment__Delaunay__graph__2.html#a873f18ec3bd12c647c684b49f99ac910", null ],
       [ "number_of_output_sites", "classCGAL_1_1Segment__Delaunay__graph__2.html#a110e6a2e70491ffe5109b8f128999e60", null ],
       [ "number_of_vertices", "classCGAL_1_1Segment__Delaunay__graph__2.html#aeb78ff99737811fd9fbdeb859f2f87cb", null ],
-      [ "operator<<", "classCGAL_1_1Segment__Delaunay__graph__2.html#ad09d4ab43d45f99167561cebcc2cbe96", null ],
-      [ "operator>>", "classCGAL_1_1Segment__Delaunay__graph__2.html#a88b6aef42e5880ee862a3d4f1d96bcd1", null ],
+      [ "operator<<", "classCGAL_1_1Segment__Delaunay__graph__2.html#ab507797fdc0b20ac27458c78269e2f35", null ],
+      [ "operator>>", "classCGAL_1_1Segment__Delaunay__graph__2.html#a5f07981544edce9443b7d83fa8898964", null ],
       [ "output_sites_begin", "classCGAL_1_1Segment__Delaunay__graph__2.html#a9aa5c8c9b078d5787fc93d7d92861a63", null ],
       [ "output_sites_end", "classCGAL_1_1Segment__Delaunay__graph__2.html#a375bacc9efc9ae442d1553b2e0ab666c", null ],
-      [ "point_container", "classCGAL_1_1Segment__Delaunay__graph__2.html#a10322040ea8ae63c251e7767deaf9017", null ],
-      [ "storage_traits", "classCGAL_1_1Segment__Delaunay__graph__2.html#aee53aa3eaf00ecb5e39924e760139956", null ],
+      [ "point_container", "classCGAL_1_1Segment__Delaunay__graph__2.html#ad4e99f21b4d29d9c7f6b4b1a0951a121", null ],
+      [ "storage_traits", "classCGAL_1_1Segment__Delaunay__graph__2.html#a9a42d008d34a5d1565dff38f0c4afb0a", null ],
       [ "swap", "classCGAL_1_1Segment__Delaunay__graph__2.html#a78495715f959802e35edb86cdffe18ca", null ],
-      [ "tds", "classCGAL_1_1Segment__Delaunay__graph__2.html#a86a4a3dd364d394417222f53ba3d60dd", null ]
+      [ "tds", "classCGAL_1_1Segment__Delaunay__graph__2.html#aa681252013b753e58d3f3864ec5e390f", null ]
     ] ],
-    [ "Segment_Delaunay_graph_face_base_2", "classCGAL_1_1Segment__Delaunay__graph__face__base__2.html", null ],
-    [ "Segment_Delaunay_graph_filtered_traits_2", "structCGAL_1_1Segment__Delaunay__graph__filtered__traits__2.html", [
+    [ "CGAL::Segment_Delaunay_graph_face_base_2< Gt, Fb >", "classCGAL_1_1Segment__Delaunay__graph__face__base__2.html", null ],
+    [ "CGAL::Segment_Delaunay_graph_filtered_traits_2< CK, CM, EK, EM, FK, FM >", "structCGAL_1_1Segment__Delaunay__graph__filtered__traits__2.html", [
       [ "Construction_kernel", "structCGAL_1_1Segment__Delaunay__graph__filtered__traits__2.html#a5bec1e99b42f9a0c1c031d33622ebb51", null ],
       [ "Construction_traits", "structCGAL_1_1Segment__Delaunay__graph__filtered__traits__2.html#aec0f12e177e56580c2a16f6bbb35bde8", null ],
       [ "Construction_traits_method_tag", "structCGAL_1_1Segment__Delaunay__graph__filtered__traits__2.html#a8ad490ef99a4a434e807c868e8661962", null ],
@@ -113,7 +113,7 @@ var group__PkgSegmentDelaunayGraph2Ref =
       [ "Kernel", "structCGAL_1_1Segment__Delaunay__graph__filtered__traits__2.html#aa3551a18fd6b6cac979353722162701e", null ],
       [ "Method_tag", "structCGAL_1_1Segment__Delaunay__graph__filtered__traits__2.html#a298cdbef9e7d3468a8cda2c04abcf159", null ]
     ] ],
-    [ "Segment_Delaunay_graph_filtered_traits_without_intersections_2", "structCGAL_1_1Segment__Delaunay__graph__filtered__traits__without__intersections__2.html", [
+    [ "CGAL::Segment_Delaunay_graph_filtered_traits_without_intersections_2< CK, CM, EK, EM, FK, FM >", "structCGAL_1_1Segment__Delaunay__graph__filtered__traits__without__intersections__2.html", [
       [ "Construction_kernel", "structCGAL_1_1Segment__Delaunay__graph__filtered__traits__without__intersections__2.html#ac52f49b402f83ddb5fd60f91b32cbdea", null ],
       [ "Construction_traits", "structCGAL_1_1Segment__Delaunay__graph__filtered__traits__without__intersections__2.html#ab7e2647a0850f4d9b2d4e16fa870a3ea", null ],
       [ "Construction_traits_method_tag", "structCGAL_1_1Segment__Delaunay__graph__filtered__traits__without__intersections__2.html#a0b317d9fe44fef6506c90ca48ba2651a", null ],
@@ -127,7 +127,7 @@ var group__PkgSegmentDelaunayGraph2Ref =
       [ "Kernel", "structCGAL_1_1Segment__Delaunay__graph__filtered__traits__without__intersections__2.html#a17ecf023f9ac8206f5f3e3788eec7516", null ],
       [ "Method_tag", "structCGAL_1_1Segment__Delaunay__graph__filtered__traits__without__intersections__2.html#a6783ea71442c7d7cefc78b8f75f8da64", null ]
     ] ],
-    [ "Segment_Delaunay_graph_hierarchy_2", "classCGAL_1_1Segment__Delaunay__graph__hierarchy__2.html", [
+    [ "CGAL::Segment_Delaunay_graph_hierarchy_2< Gt, St, STag, DS >", "classCGAL_1_1Segment__Delaunay__graph__hierarchy__2.html", [
       [ "Base", "classCGAL_1_1Segment__Delaunay__graph__hierarchy__2.html#a362db955ce0b4870e49c7711a3e25a90", null ],
       [ "Segments_in_hierarchy_tag", "classCGAL_1_1Segment__Delaunay__graph__hierarchy__2.html#a7ecf8e2c710a0db743050e553d27eab6", null ],
       [ "Segment_Delaunay_graph_hierarchy_2", "classCGAL_1_1Segment__Delaunay__graph__hierarchy__2.html#a87003a24dc7b4d87373a4273c8142199", null ],
@@ -135,43 +135,43 @@ var group__PkgSegmentDelaunayGraph2Ref =
       [ "operator<<", "classCGAL_1_1Segment__Delaunay__graph__hierarchy__2.html#a825f652bb2b95c5dd862ae554eec363e", null ],
       [ "operator>>", "classCGAL_1_1Segment__Delaunay__graph__hierarchy__2.html#a9faaeb3c538907219be1066de61073f0", null ]
     ] ],
-    [ "Segment_Delaunay_graph_hierarchy_vertex_base_2", "classCGAL_1_1Segment__Delaunay__graph__hierarchy__vertex__base__2.html", null ],
-    [ "Segment_Delaunay_graph_site_2", "classCGAL_1_1Segment__Delaunay__graph__site__2.html", [
+    [ "CGAL::Segment_Delaunay_graph_hierarchy_vertex_base_2< Vbb >", "classCGAL_1_1Segment__Delaunay__graph__hierarchy__vertex__base__2.html", null ],
+    [ "CGAL::Segment_Delaunay_graph_site_2< K >", "classCGAL_1_1Segment__Delaunay__graph__site__2.html", [
       [ "Kernel", "classCGAL_1_1Segment__Delaunay__graph__site__2.html#a8dab56b0503c28e80bc2221d8b686942", null ]
     ] ],
-    [ "Segment_Delaunay_graph_storage_site_2", "classCGAL_1_1Segment__Delaunay__graph__storage__site__2.html", [
+    [ "CGAL::Segment_Delaunay_graph_storage_site_2< St >", "classCGAL_1_1Segment__Delaunay__graph__storage__site__2.html", [
       [ "Storage_traits", "classCGAL_1_1Segment__Delaunay__graph__storage__site__2.html#aa85172d5eab2a89d6543d6ebe2a8a1f9", null ]
     ] ],
-    [ "Segment_Delaunay_graph_storage_site_with_info_2", "classCGAL_1_1Segment__Delaunay__graph__storage__site__with__info__2.html", [
+    [ "CGAL::Segment_Delaunay_graph_storage_site_with_info_2< STraits, Info_, Base >", "classCGAL_1_1Segment__Delaunay__graph__storage__site__with__info__2.html", [
       [ "Has_info_tag", "structCGAL_1_1Segment__Delaunay__graph__storage__site__with__info__2_1_1Has__info__tag.html", null ],
       [ "Geom_traits", "classCGAL_1_1Segment__Delaunay__graph__storage__site__with__info__2.html#a14cd51f58ab0a01202ce9f2c1b0bc76b", null ],
       [ "Info", "classCGAL_1_1Segment__Delaunay__graph__storage__site__with__info__2.html#affd62f88aeaa8e6f4c44e92b3d980b0a", null ],
       [ "Point_handle", "classCGAL_1_1Segment__Delaunay__graph__storage__site__with__info__2.html#ad65bcc279a67c1dfd266f1feb3b72e4b", null ],
       [ "Site_2", "classCGAL_1_1Segment__Delaunay__graph__storage__site__with__info__2.html#af630d2c830ce25b4e7648438716817e7", null ],
       [ "Storage_traits", "classCGAL_1_1Segment__Delaunay__graph__storage__site__with__info__2.html#a02b29836422414e2b4b2741681cb38c0", null ],
-      [ "info", "classCGAL_1_1Segment__Delaunay__graph__storage__site__with__info__2.html#a18c8267c8fbac18696d4de4d96691f0e", null ],
+      [ "info", "classCGAL_1_1Segment__Delaunay__graph__storage__site__with__info__2.html#a1ce1d5c5aa22dab71b58829d0d3204bc", null ],
       [ "info_has_been_set", "classCGAL_1_1Segment__Delaunay__graph__storage__site__with__info__2.html#ae3f569eb027813f6b194cc9517c11197", null ],
       [ "set_info", "classCGAL_1_1Segment__Delaunay__graph__storage__site__with__info__2.html#a1044d16c39dfd8c7b7218f0ba4bcf0a6", null ]
     ] ],
-    [ "Segment_Delaunay_graph_storage_traits_2", "classCGAL_1_1Segment__Delaunay__graph__storage__traits__2.html", [
+    [ "CGAL::Segment_Delaunay_graph_storage_traits_2< Gt >", "classCGAL_1_1Segment__Delaunay__graph__storage__traits__2.html", [
       [ "Storage_site_2", "classCGAL_1_1Segment__Delaunay__graph__storage__traits__2.html#acee511bef2aaa4786ff52fb65f02537f", null ]
     ] ],
-    [ "Segment_Delaunay_graph_storage_traits_with_info_2", "classCGAL_1_1Segment__Delaunay__graph__storage__traits__with__info__2.html", [
+    [ "CGAL::Segment_Delaunay_graph_storage_traits_with_info_2< Gt, Info, Converter, Merger >", "classCGAL_1_1Segment__Delaunay__graph__storage__traits__with__info__2.html", [
       [ "Convert_info", "classCGAL_1_1Segment__Delaunay__graph__storage__traits__with__info__2.html#a415be097fb894baa9194e9061922cd9b", null ],
       [ "Geom_traits", "classCGAL_1_1Segment__Delaunay__graph__storage__traits__with__info__2.html#af753af803594809a2e8246babf67ab5a", null ],
       [ "Info", "classCGAL_1_1Segment__Delaunay__graph__storage__traits__with__info__2.html#a703961bc12b2455dc8132700588ac2bd", null ],
       [ "Merge_info", "classCGAL_1_1Segment__Delaunay__graph__storage__traits__with__info__2.html#af43d59c114cd8297fe5df43f4c2e1a81", null ],
       [ "Storage_site_2", "classCGAL_1_1Segment__Delaunay__graph__storage__traits__with__info__2.html#a633bc0d0f28717bd4c908591a2e87ec8", null ]
     ] ],
-    [ "Segment_Delaunay_graph_traits_2", "structCGAL_1_1Segment__Delaunay__graph__traits__2.html", [
+    [ "CGAL::Segment_Delaunay_graph_traits_2< K, MTag >", "structCGAL_1_1Segment__Delaunay__graph__traits__2.html", [
       [ "Intersections_tag", "structCGAL_1_1Segment__Delaunay__graph__traits__2.html#afa3382b7657c78e3c1ca24cee9158536", null ],
       [ "Kernel", "structCGAL_1_1Segment__Delaunay__graph__traits__2.html#ab927c9463ab9ca862ada5808e5648759", null ],
       [ "Method_tag", "structCGAL_1_1Segment__Delaunay__graph__traits__2.html#ab8cdc7118f04fc6d98e1ae61bf944275", null ]
     ] ],
-    [ "Segment_Delaunay_graph_traits_without_intersections_2", "structCGAL_1_1Segment__Delaunay__graph__traits__without__intersections__2.html", [
+    [ "CGAL::Segment_Delaunay_graph_traits_without_intersections_2< K, MTag >", "structCGAL_1_1Segment__Delaunay__graph__traits__without__intersections__2.html", [
       [ "Intersections_tag", "structCGAL_1_1Segment__Delaunay__graph__traits__without__intersections__2.html#af734076fec7f32afe962f2a5e6a9f4e2", null ],
       [ "Kernel", "structCGAL_1_1Segment__Delaunay__graph__traits__without__intersections__2.html#aa97a104931222be0fddf598a3a0ee9b1", null ],
       [ "Method_tag", "structCGAL_1_1Segment__Delaunay__graph__traits__without__intersections__2.html#a5bd3a45c785dc0190d4c593d4da62121", null ]
     ] ],
-    [ "Segment_Delaunay_graph_vertex_base_2", "classCGAL_1_1Segment__Delaunay__graph__vertex__base__2.html", null ]
+    [ "CGAL::Segment_Delaunay_graph_vertex_base_2< St, Vb >", "classCGAL_1_1Segment__Delaunay__graph__vertex__base__2.html", null ]
 ];
\ No newline at end of file
