@@ -91,13 +91,15 @@ var group__PkgShapeDetectionRGOnPoints =
       [ "Least_squares_plane_fit_region_for_point_set", "group__PkgShapeDetectionRGOnPointSet3.html#ga16300a0ce273a2abc4f32848bd176aed", null ],
       [ "make_least_squares_plane_fit_region", "group__PkgShapeDetectionRGOnPointSet3.html#gac4c1c31e24bf462c6a302007fef90538", null ]
     ] ],
-    [ "CGAL::Shape_detection::Point_set::Least_squares_plane_fit_sorting< GeomTraits, Item_, NeighborQuery, PointMap >", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html", [
-      [ "Item", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#a86f2150162af7d2221a8a8c2120e6da1", null ],
-      [ "Seed_range", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#a1dd00b4a4bf1f697ba535205a2c25e2a", null ],
-      [ "Least_squares_plane_fit_sorting", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#ae092d06c70731db484a6686f5dd8b7f8", null ],
-      [ "ordered", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#a151cebebf038b696e5ba72122ba85c98", null ],
-      [ "sort", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#ac824391a05ca998f4f6fd758fa690e30", null ],
-      [ "Least_squares_plane_fit_sorting_for_point_set", "group__PkgShapeDetectionRGOnPointSet3.html#ga516212258dd2ae3b97a3f664692e50db", null ],
+    [ "CGAL::Shape_detection::Point_set::Least_squares_plane_fit_sorting< GeomTraits, Item_, NeighborQuery, PointMap, NormalMap >", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html", [
+      [ "Item", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#a59236f525ca0a7b01ec2bd916adfc594", null ],
+      [ "Seed_range", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#a1c57d994ccd1e376647c25bd589479c3", null ],
+      [ "Least_squares_plane_fit_sorting", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#afcbf9046fd5ac3f351fa239982f10da1", null ],
+      [ "mean_deviation", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#a9829c533f9c990717512cfe9612b50f8", null ],
+      [ "mean_distance", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#aac029d1331c16876eea7769e43031232", null ],
+      [ "ordered", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#a2a0076afad63cb8216efa9b1285994db", null ],
+      [ "sort", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#a00884ad4be96fc5c0bdf54f6d0ebbdbd", null ],
+      [ "Least_squares_plane_fit_sorting_for_point_set", "group__PkgShapeDetectionRGOnPointSet3.html#gaa578dfccdbfca9625896790cfa0b19bd", null ],
       [ "make_least_squares_plane_fit_sorting", "group__PkgShapeDetectionRGOnPointSet3.html#ga2123a8a09f0799bd9083f25900e4cec9", null ]
     ] ],
     [ "CGAL::Shape_detection::Point_set::Least_squares_sphere_fit_region< GeomTraits, Item_, PointMap, NormalMap >", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__region.html", [
