@@ -24,7 +24,7 @@
 */
 var NAVTREE =
 [
-  [ "CGAL 6.0 - Shape Detection", "index.html", [
+  [ "CGAL 6.0.1 - Shape Detection", "index.html", [
     [ "User Manual", "index.html", "index" ],
     [ "Reference Manual", "modules.html", "modules" ],
     [ "Bibliography", "citelist.html", null ],
@@ -36,7 +36,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "Efficient__RANSAC_8h.html",
-"classEfficientRANSACTraits.html#a3a676e02a525238904d916637b4667fc"
+"classEfficientRANSACTraits.html#a270617107d02998b9130eea0ea7a754e"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
