@@ -1,17 +1,17 @@
 var NAVTREEINDEX0 =
 {
-"Straight_skeleton_2_2Create_offset_polygons_2_8cpp-example.html":[6,0],
-"Straight_skeleton_2_2Create_saop_from_polygon_with_holes_2_8cpp-example.html":[6,1],
-"Straight_skeleton_2_2Create_skeleton_and_offset_polygons_2_8cpp-example.html":[6,2],
-"Straight_skeleton_2_2Create_skeleton_and_offset_polygons_with_holes_2_8cpp-example.html":[6,3],
-"Straight_skeleton_2_2Create_straight_skeleton_2_8cpp-example.html":[6,4],
-"Straight_skeleton_2_2Create_straight_skeleton_from_polygon_with_holes_2_8cpp-example.html":[6,5],
-"Straight_skeleton_2_2Low_level_API_8cpp-example.html":[6,7],
-"Straight_skeleton_2_2Show_offset_polygon_8cpp-example.html":[6,8],
-"Straight_skeleton_2_2Show_straight_skeleton_8cpp-example.html":[6,9],
-"Straight_skeleton_2_2extrude_skeleton_8cpp-example.html":[6,6],
-"annotated.html":[5],
-"citelist.html":[4],
+"Straight_skeleton_2_2Create_offset_polygons_2_8cpp-example.html":[4,0],
+"Straight_skeleton_2_2Create_saop_from_polygon_with_holes_2_8cpp-example.html":[4,1],
+"Straight_skeleton_2_2Create_skeleton_and_offset_polygons_2_8cpp-example.html":[4,2],
+"Straight_skeleton_2_2Create_skeleton_and_offset_polygons_with_holes_2_8cpp-example.html":[4,3],
+"Straight_skeleton_2_2Create_straight_skeleton_2_8cpp-example.html":[4,4],
+"Straight_skeleton_2_2Create_straight_skeleton_from_polygon_with_holes_2_8cpp-example.html":[4,5],
+"Straight_skeleton_2_2Low_level_API_8cpp-example.html":[4,7],
+"Straight_skeleton_2_2Show_offset_polygon_8cpp-example.html":[4,8],
+"Straight_skeleton_2_2Show_straight_skeleton_8cpp-example.html":[4,9],
+"Straight_skeleton_2_2extrude_skeleton_8cpp-example.html":[4,6],
+"annotated.html":[3],
+"citelist.html":[2],
 "classCGAL_1_1Polygon__offset__builder__2.html":[1,0,1,0],
 "classCGAL_1_1Polygon__offset__builder__2.html#a19712eec08ba00eec3e827ce3300414c":[1,0,1,0,0],
 "classCGAL_1_1Polygon__offset__builder__2.html#a1b075f4188a94f209a4a6b14ee25f23b":[1,0,1,0,1],
@@ -22,26 +22,26 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Straight__skeleton__2.html":[1,0,1,2],
 "classCGAL_1_1Straight__skeleton__2.html#a539e4c8e38ebba214e06bdc778d7f0b5":[1,0,1,2,0],
 "classCGAL_1_1Straight__skeleton__builder__2.html":[1,0,1,4],
-"classCGAL_1_1Straight__skeleton__builder__2.html#a15f149a429a13f6950af70d8969bf1cb":[1,0,1,4,5],
-"classCGAL_1_1Straight__skeleton__builder__2.html#a244d5a2713e1fab6afee34ed811ba44c":[1,0,1,4,6],
+"classCGAL_1_1Straight__skeleton__builder__2.html#a1ba257b3fd2257b981d2c65d9faa8b17":[1,0,1,4,5],
+"classCGAL_1_1Straight__skeleton__builder__2.html#a2a1ac9b05f474dcf5c7f736ca66713af":[1,0,1,4,7],
 "classCGAL_1_1Straight__skeleton__builder__2.html#a50af247c6638f4556be236af27fa48b8":[1,0,1,4,2],
+"classCGAL_1_1Straight__skeleton__builder__2.html#a5ac872b690910d5c9a6f3310bd3eb2a6":[1,0,1,4,6],
 "classCGAL_1_1Straight__skeleton__builder__2.html#a5d2b28c96cd7d7cab3c3e6a9ffdc1452":[1,0,1,4,3],
-"classCGAL_1_1Straight__skeleton__builder__2.html#a60671912914d8d1dde52859af9dd3a6b":[1,0,1,4,4],
 "classCGAL_1_1Straight__skeleton__builder__2.html#a8356d8127178ead3a96d53b6aeeff3a0":[1,0,1,4,1],
 "classCGAL_1_1Straight__skeleton__builder__2.html#a94321d949d9c7fa8b3789b68c42e1f86":[1,0,1,4,0],
-"classCGAL_1_1Straight__skeleton__builder__2.html#af8356cd95d0a9850dbd9cd77c653939a":[1,0,1,4,7],
+"classCGAL_1_1Straight__skeleton__builder__2.html#a9a8f917f2922dd18cb34e00717f254fb":[1,0,1,4,4],
 "classCGAL_1_1Straight__skeleton__builder__traits__2.html":[1,0,1,5],
 "classCGAL_1_1Straight__skeleton__face__base__2.html":[1,0,2,2],
 "classCGAL_1_1Straight__skeleton__halfedge__base__2.html":[1,0,2,3],
 "classCGAL_1_1Straight__skeleton__vertex__base__2.html":[1,0,2,4],
 "classCGAL_1_1Trisegment__2.html":[1,0,1,6],
-"classCGAL_1_1Trisegment__2.html#a1ed6b2616b3de2f1b80f75c4f8cfcafd":[1,0,1,6,1],
-"classCGAL_1_1Trisegment__2.html#a3760790895f3d770bd0a44dd28551060":[1,0,1,6,3],
-"classCGAL_1_1Trisegment__2.html#a4c96133bf19886ebaa32038b79ba4235":[1,0,1,6,6],
-"classCGAL_1_1Trisegment__2.html#a511ad057d7dd92dd41018cda2fea9390":[1,0,1,6,5],
+"classCGAL_1_1Trisegment__2.html#a5380ebd324b9e74b284c8ce3c27a9a63":[1,0,1,6,5],
 "classCGAL_1_1Trisegment__2.html#a5617de0645277aa15fa3534bc6fbc2f4":[1,0,1,6,0],
-"classCGAL_1_1Trisegment__2.html#addddb696742f3fd25797b304cc279cf9":[1,0,1,6,2],
-"classCGAL_1_1Trisegment__2.html#aedeb4b2084fd3f8003aa6cc6f40cdcf2":[1,0,1,6,4],
+"classCGAL_1_1Trisegment__2.html#a9f254b56d81e431e6ea0dbbf03211339":[1,0,1,6,3],
+"classCGAL_1_1Trisegment__2.html#abce2aca993e17a404e37d336a717434b":[1,0,1,6,4],
+"classCGAL_1_1Trisegment__2.html#ad94e14644c1cf0565e5229cd18c88146":[1,0,1,6,2],
+"classCGAL_1_1Trisegment__2.html#af245a65216f287655d65b4ba0d129323":[1,0,1,6,6],
+"classCGAL_1_1Trisegment__2.html#afba916e710a0444936dc4dce6b6767f8":[1,0,1,6,1],
 "classPolygonOffsetBuilderTraits__2.html":[1,0,0,0],
 "classPolygonOffsetBuilderTraits__2.html#a310d4094cb7654095fac96ec1c0d08c1":[1,0,0,0,2],
 "classPolygonOffsetBuilderTraits__2.html#a31a165302c96cc75c05ae6fe9b49cfe5":[1,0,0,0,3],
@@ -108,9 +108,9 @@ var NAVTREEINDEX0 =
 "classStraightSkeletonHalfedge__2.html#aeca5335bd44cf5995a6ef4b2fc78edc6":[1,0,0,5,1],
 "classStraightSkeletonItemsConverter__2.html":[1,0,0,6],
 "classStraightSkeletonItemsConverter__2.html#a2354f89ad7b40735f6018a33bcc8220f":[1,0,0,6,1],
-"classStraightSkeletonItemsConverter__2.html#a3bebb9671fe9ac3a30f3daebb138f5ca":[1,0,0,6,6],
+"classStraightSkeletonItemsConverter__2.html#a3bebb9671fe9ac3a30f3daebb138f5ca":[1,0,0,6,8],
 "classStraightSkeletonItemsConverter__2.html#a3f99e28af5e36395f711aa540d74b544":[1,0,0,6,7],
-"classStraightSkeletonItemsConverter__2.html#a402e4328df6e1e26fa647aa8efb84045":[1,0,0,6,8],
+"classStraightSkeletonItemsConverter__2.html#a402e4328df6e1e26fa647aa8efb84045":[1,0,0,6,6],
 "classStraightSkeletonItemsConverter__2.html#a73c1266bb1cfcd03487c0324d69a4ca1":[1,0,0,6,5],
 "classStraightSkeletonItemsConverter__2.html#ab2fd981b7c0bfe859fe3fdbc97934fd9":[1,0,0,6,0],
 "classStraightSkeletonItemsConverter__2.html#ad0846841e9700e7584d96614eb5f0b67":[1,0,0,6,2],
@@ -121,8 +121,8 @@ var NAVTREEINDEX0 =
 "classStraightSkeletonVertex__2.html#a246459b1b280e8b73416356a6d10c2d0":[1,0,0,7,10],
 "classStraightSkeletonVertex__2.html#a2a8dc167a2ef64559e2d409b30534278":[1,0,0,7,9],
 "classStraightSkeletonVertex__2.html#a2fc13209c6cdd2cc8cc0c628af4c2303":[1,0,0,7,18],
+"classStraightSkeletonVertex__2.html#a30216de5647dbf95a8414eb4dd8b8684":[1,0,0,7,16],
 "classStraightSkeletonVertex__2.html#a3965cb34f5374d039dcc38b18145960d":[1,0,0,7,15],
-"classStraightSkeletonVertex__2.html#a427161c098affc0bd605ddaf5bb30cb0":[1,0,0,7,16],
 "classStraightSkeletonVertex__2.html#a4d48abde89a2f95992cf42936e3798bd":[1,0,0,7,17],
 "classStraightSkeletonVertex__2.html#a50ac0cbb14775a23da321daa98b20612":[1,0,0,7,3],
 "classStraightSkeletonVertex__2.html#a579d7224c8b55c50a02a53ac165df18f":[1,0,0,7,11],
@@ -141,7 +141,7 @@ var NAVTREEINDEX0 =
 "classStraightSkeleton__2.html#a47b5ac9f2c3ee6340f2e11abb1ca7777":[1,0,0,1,1],
 "classStraightSkeleton__2.html#a67076c8583c3d12b7ec436db7e83d8b2":[1,0,0,1,0],
 "classStraightSkeleton__2.html#ad0a9b9d28e3a4f92468f83d013a4a760":[1,0,0,1,2],
-"examples.html":[6],
+"examples.html":[4],
 "group__PkgStraightSkeleton2Auxiliary.html":[1,0,2],
 "group__PkgStraightSkeleton2Classes.html":[1,0,1],
 "group__PkgStraightSkeleton2Concepts.html":[1,0,0],
@@ -149,37 +149,36 @@ var NAVTREEINDEX0 =
 "group__PkgStraightSkeleton2Extrusion.html#ga0d1ccb10934bb54fb88a6174f30dfe49":[1,0,3,0],
 "group__PkgStraightSkeleton2Functions.html":[1,0,4],
 "group__PkgStraightSkeleton2OffsetFunctions.html":[1,0,4,2],
-"group__PkgStraightSkeleton2OffsetFunctions.html#ga095d8eb8c2f46131babbaa58a6e0402d":[1,0,4,2,2],
-"group__PkgStraightSkeleton2OffsetFunctions.html#ga0aa0c1fb3dddefde4f38b6e85a5d8537":[1,0,4,2,9],
-"group__PkgStraightSkeleton2OffsetFunctions.html#ga2ac8efaf21d11e44fd75ba0cb16f6a44":[1,0,4,2,5],
-"group__PkgStraightSkeleton2OffsetFunctions.html#ga38559e740e1c9797def58156832ab245":[1,0,4,2,7],
-"group__PkgStraightSkeleton2OffsetFunctions.html#ga3cbb858d699dd108bbd374b957b3fbcf":[1,0,4,2,1],
-"group__PkgStraightSkeleton2OffsetFunctions.html#ga3cd75bf3c0bf0e1d932564738a49bb44":[1,0,4,2,8],
-"group__PkgStraightSkeleton2OffsetFunctions.html#ga558e874bf4e24a79b30449b10dedc0be":[1,0,4,2,4],
-"group__PkgStraightSkeleton2OffsetFunctions.html#ga80a83d9b770bb3bfda6401b0cc5cc79f":[1,0,4,2,10],
-"group__PkgStraightSkeleton2OffsetFunctions.html#ga9edfd734009699bb4a331e118661dfb5":[1,0,4,2,6],
-"group__PkgStraightSkeleton2OffsetFunctions.html#gaad32e75e20e3146ad121d63d60688726":[1,0,4,2,3],
+"group__PkgStraightSkeleton2OffsetFunctions.html#ga36fe6fd001343f6cd0a3e8b06d1c325c":[1,0,4,2,10],
+"group__PkgStraightSkeleton2OffsetFunctions.html#ga4baa6cdc2cc19c341be875742387254b":[1,0,4,2,6],
+"group__PkgStraightSkeleton2OffsetFunctions.html#ga52736ea80b6df08be011d5d66e26a543":[1,0,4,2,5],
+"group__PkgStraightSkeleton2OffsetFunctions.html#ga7627d015c03abaea59b144576afebf70":[1,0,4,2,4],
+"group__PkgStraightSkeleton2OffsetFunctions.html#ga80c0848e0145bbd531b1fc178fd07d33":[1,0,4,2,1],
+"group__PkgStraightSkeleton2OffsetFunctions.html#ga84423baa5902a7d6c2f8278f93d82f32":[1,0,4,2,2],
+"group__PkgStraightSkeleton2OffsetFunctions.html#gabe025331b6e803f2f942305123a02306":[1,0,4,2,8],
+"group__PkgStraightSkeleton2OffsetFunctions.html#gaee073b6bd62fb5722bad41528647ec30":[1,0,4,2,9],
+"group__PkgStraightSkeleton2OffsetFunctions.html#gaee243d012e7f942b4d1365dc307546b8":[1,0,4,2,3],
+"group__PkgStraightSkeleton2OffsetFunctions.html#gaf0d0e8321d70cd97e6441b6ce77bdc89":[1,0,4,2,7],
 "group__PkgStraightSkeleton2OffsetFunctions.html#gafd9733f1c41a778c6e274017ddae9ade":[1,0,4,2,0],
 "group__PkgStraightSkeleton2Ref.html":[1,0],
 "group__PkgStraightSkeleton2SkeletonFunctions.html":[1,0,4,0],
-"group__PkgStraightSkeleton2SkeletonFunctions.html#ga35ba441db99ed7bed70e8c5b3c9bb8c2":[1,0,4,0,2],
-"group__PkgStraightSkeleton2SkeletonFunctions.html#ga6431d82e9656a4e8652236b27021c0b0":[1,0,4,0,3],
-"group__PkgStraightSkeleton2SkeletonFunctions.html#ga9be44c0c7e2f86fb820b47f2e743d86b":[1,0,4,0,1],
-"group__PkgStraightSkeleton2SkeletonFunctions.html#gaaa90a0e8062765321ec2abe3b82fa53f":[1,0,4,0,0],
-"group__PkgStraightSkeleton2SkeletonFunctions.html#gae263563f21a88de495eb9d7982ed6eca":[1,0,4,0,4],
+"group__PkgStraightSkeleton2SkeletonFunctions.html#ga02808f3323f2e728f04e982020d1e9fd":[1,0,4,0,1],
+"group__PkgStraightSkeleton2SkeletonFunctions.html#ga75b6c1f14dc887bc51ae6e000d608855":[1,0,4,0,2],
+"group__PkgStraightSkeleton2SkeletonFunctions.html#ga83229dd3649bc7624d7c6f2733c2edde":[1,0,4,0,0],
+"group__PkgStraightSkeleton2SkeletonFunctions.html#ga9a8b0749901ca3a551d4f15a45bc0437":[1,0,4,0,4],
+"group__PkgStraightSkeleton2SkeletonFunctions.html#gae1eec4fe2422502d32906f11306a4979":[1,0,4,0,3],
 "group__PkgStraightSkeleton2WeightedOffsetFunctions.html":[1,0,4,3],
-"group__PkgStraightSkeleton2WeightedOffsetFunctions.html#ga5e8f9939087882613821de62cae4aef9":[1,0,4,3,1],
-"group__PkgStraightSkeleton2WeightedOffsetFunctions.html#gaa2dfc0a322cfa222f578a6dc066f5885":[1,0,4,3,0],
-"group__PkgStraightSkeleton2WeightedOffsetFunctions.html#gadf9178359f09110c463c7d72b77638f9":[1,0,4,3,2],
+"group__PkgStraightSkeleton2WeightedOffsetFunctions.html#ga01cf19d841b9d7b8c022560011308315":[1,0,4,3,0],
+"group__PkgStraightSkeleton2WeightedOffsetFunctions.html#ga37e2dd0a30bf5eb8c840a51882b12914":[1,0,4,3,2],
+"group__PkgStraightSkeleton2WeightedOffsetFunctions.html#ga773095b0af928be7e38960c7ae46d00d":[1,0,4,3,1],
 "group__PkgStraightSkeleton2WeightedSkeletonFunctions.html":[1,0,4,1],
-"group__PkgStraightSkeleton2WeightedSkeletonFunctions.html#ga1f2ca42efa41ed06a1505c2f291a6cb5":[1,0,4,1,1],
-"group__PkgStraightSkeleton2WeightedSkeletonFunctions.html#ga2dd4aed2af1592742e5514cfe14ebafb":[1,0,4,1,4],
-"group__PkgStraightSkeleton2WeightedSkeletonFunctions.html#ga47341a662706227c6b4aa808dd17cf32":[1,0,4,1,2],
-"group__PkgStraightSkeleton2WeightedSkeletonFunctions.html#ga55676e4a7a1388b9a944a4b6c90c2c3b":[1,0,4,1,3],
-"group__PkgStraightSkeleton2WeightedSkeletonFunctions.html#ga9d62043b60b1e823622154899d7e08dd":[1,0,4,1,0],
-"hasModels.html":[3],
-"index.html":[0],
+"group__PkgStraightSkeleton2WeightedSkeletonFunctions.html#ga325dbd960b6d715f39325fa2db01d92a":[1,0,4,1,3],
+"group__PkgStraightSkeleton2WeightedSkeletonFunctions.html#ga68bd822b108199be009e58c9b30a3c6c":[1,0,4,1,1],
+"group__PkgStraightSkeleton2WeightedSkeletonFunctions.html#ga75a14b882aab08c4e0a8b09c1a06a7f2":[1,0,4,1,0],
+"group__PkgStraightSkeleton2WeightedSkeletonFunctions.html#gadabc695ea752780c073bc156fecd22c3":[1,0,4,1,4],
+"group__PkgStraightSkeleton2WeightedSkeletonFunctions.html#gaf1060822f8bac7f57ca961b04a08fac8":[1,0,4,1,2],
 "index.html":[],
+"index.html":[0],
 "index.html#Straight_skeleton_22DContour":[0,1,0],
 "index.html#Straight_skeleton_22DPolygonwithHoles":[0,1,1],
 "index.html#Straight_skeleton_2Comparison":[0,0,1],
@@ -204,16 +203,14 @@ var NAVTREEINDEX0 =
 "index.html#Straight_skeleton_2StraightSkeletonofa2D":[0,1,2],
 "index.html#Straight_skeleton_2Usages":[0,2],
 "index.html#Straight_skeleton_2Weights":[0,1,3],
-"models.html":[2],
 "modules.html":[1],
-"namespaceCGAL.html":[5,0],
 "pages.html":[],
 "structCGAL_1_1Dummy__straight__skeleton__builder__2__visitor.html":[1,0,1,3],
 "structCGAL_1_1Straight__skeleton__converter__2.html":[1,0,2,0],
-"structCGAL_1_1Straight__skeleton__converter__2.html#a08d45dcf5230e3bca2a93174eab9dd4d":[1,0,2,0,4],
 "structCGAL_1_1Straight__skeleton__converter__2.html#a276b75a962784d286aa92afbebf6624a":[1,0,2,0,2],
 "structCGAL_1_1Straight__skeleton__converter__2.html#a4f8077dfb9bb05b0a38f600789248caa":[1,0,2,0,0],
 "structCGAL_1_1Straight__skeleton__converter__2.html#a870ac81e7d4c542d8cb1917fa2fd105d":[1,0,2,0,3],
+"structCGAL_1_1Straight__skeleton__converter__2.html#a953bb6d2a42530ff51d7d57fe5591791":[1,0,2,0,4],
 "structCGAL_1_1Straight__skeleton__converter__2.html#af42d188361f1fa1002f67f2e738e20b1":[1,0,2,0,1],
 "structCGAL_1_1Straight__skeleton__items__converter__2.html":[1,0,2,1],
 "structCGAL_1_1Straight__skeleton__items__converter__2.html#abbab8379e228aa0281a32e5fc03b2193":[1,0,2,1,0]
