@@ -24,7 +24,7 @@
 */
 var NAVTREE =
 [
-  [ "CGAL 6.0 - IO Streams", "index.html", [
+  [ "CGAL 6.0.1 - IO Streams", "index.html", [
     [ "User Manual", "index.html", "index" ],
     [ "Reference Manual", "modules.html", "modules" ],
     [ "Supported File Formats", "IOStreamSupportedFileFormats.html", [
