@@ -1,17 +1,15 @@
 var NAVTREEINDEX0 =
 {
-".html":[5,0],
-".html":[5,0,0],
-"Surface_mesh_parameterization_2ARAP_parameterization_8cpp-example.html":[6,0],
-"Surface_mesh_parameterization_2discrete_authalic_8cpp-example.html":[6,1],
-"Surface_mesh_parameterization_2iterative_authalic_parameterizer_8cpp-example.html":[6,2],
-"Surface_mesh_parameterization_2lscm_8cpp-example.html":[6,3],
-"Surface_mesh_parameterization_2orbifold_8cpp-example.html":[6,4],
-"Surface_mesh_parameterization_2seam_Polyhedron_3_8cpp-example.html":[6,5],
-"Surface_mesh_parameterization_2simple_parameterization_8cpp-example.html":[6,6],
-"Surface_mesh_parameterization_2square_border_parameterizer_8cpp-example.html":[6,7],
-"annotated.html":[5],
-"citelist.html":[4],
+"Surface_mesh_parameterization_2ARAP_parameterization_8cpp-example.html":[4,0],
+"Surface_mesh_parameterization_2discrete_authalic_8cpp-example.html":[4,1],
+"Surface_mesh_parameterization_2iterative_authalic_parameterizer_8cpp-example.html":[4,7],
+"Surface_mesh_parameterization_2lscm_8cpp-example.html":[4,2],
+"Surface_mesh_parameterization_2orbifold_8cpp-example.html":[4,3],
+"Surface_mesh_parameterization_2seam_Polyhedron_3_8cpp-example.html":[4,4],
+"Surface_mesh_parameterization_2simple_parameterization_8cpp-example.html":[4,5],
+"Surface_mesh_parameterization_2square_border_parameterizer_8cpp-example.html":[4,6],
+"annotated.html":[3],
+"citelist.html":[2],
 "classCGAL_1_1Surface__mesh__parameterization_1_1ARAP__parameterizer__3.html":[1,0,3,1],
 "classCGAL_1_1Surface__mesh__parameterization_1_1ARAP__parameterizer__3.html#a22a9990122daac6ec3f5b795d9e03c52":[1,0,3,1,1],
 "classCGAL_1_1Surface__mesh__parameterization_1_1ARAP__parameterizer__3.html#a3021cd8840c3df66a016cfecc32c7c3d":[1,0,3,1,8],
@@ -59,26 +57,26 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Surface__mesh__parameterization_1_1Fixed__border__parameterizer__3.html#a1f741da22468c5e9b7d22bb7bef7d72d":[1,0,3,5,4],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Fixed__border__parameterizer__3.html#a21de062efd9a812bb35f32d4e7617803":[1,0,3,5,1],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Fixed__border__parameterizer__3.html#a4419f2fd8165db3e357acff848c705fa":[1,0,3,5,7],
+"classCGAL_1_1Surface__mesh__parameterization_1_1Fixed__border__parameterizer__3.html#a4db539233eaa58b7f41f0ba24d320312":[1,0,3,5,10],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Fixed__border__parameterizer__3.html#a723e8cfa8199a52cb3bd1a309273b1a8":[1,0,3,5,14],
+"classCGAL_1_1Surface__mesh__parameterization_1_1Fixed__border__parameterizer__3.html#a7b82f03f86d6e300f9c4a3f515cb0093":[1,0,3,5,11],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Fixed__border__parameterizer__3.html#a801c1161ac85bfcb98baf692c96bc979":[1,0,3,5,3],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Fixed__border__parameterizer__3.html#a88fa07fd2b024e87466071ef8da5fcee":[1,0,3,5,13],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Fixed__border__parameterizer__3.html#a911b7def89e06fabb4f21aae0de572a1":[1,0,3,5,12],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Fixed__border__parameterizer__3.html#a94d1dd31f1bb40444f24c28d257afc81":[1,0,3,5,0],
-"classCGAL_1_1Surface__mesh__parameterization_1_1Fixed__border__parameterizer__3.html#aa3c60680ccd35b8bf14f4885b1cd735f":[1,0,3,5,10],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Fixed__border__parameterizer__3.html#aaaf968b62605620015e8d4be0c3f6471":[1,0,3,5,9],
-"classCGAL_1_1Surface__mesh__parameterization_1_1Fixed__border__parameterizer__3.html#ab3f53a9fc3dc7b5b70b5d4cd061abbd2":[1,0,3,5,11],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Fixed__border__parameterizer__3.html#abdb715d52ac169c6f6adc7c4f915ee12":[1,0,3,5,6],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Fixed__border__parameterizer__3.html#ad5f32f3835d4341cbc02671bdb9064b3":[1,0,3,5,2],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Fixed__border__parameterizer__3.html#ae310fbbf17605ac130e357e6e2c46200":[1,0,3,5,8],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Iterative__authalic__parameterizer__3.html":[1,0,3,6],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Iterative__authalic__parameterizer__3.html#a2ae8570b5c4627a3a0bc2b2ebee249e7":[1,0,3,6,7],
-"classCGAL_1_1Surface__mesh__parameterization_1_1Iterative__authalic__parameterizer__3.html#a37663dba31b70f65e7a309203c0aa135":[1,0,3,6,4],
+"classCGAL_1_1Surface__mesh__parameterization_1_1Iterative__authalic__parameterizer__3.html#a404ba6643a0c9455859adee3d0e02379":[1,0,3,6,5],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Iterative__authalic__parameterizer__3.html#a4ef4796c3bf445e9e958a1d2108bcaa9":[1,0,3,6,6],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Iterative__authalic__parameterizer__3.html#a506bc11c54cc8255119f9776743c3840":[1,0,3,6,0],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Iterative__authalic__parameterizer__3.html#a86cbf9a07dd945815abd980d668ba686":[1,0,3,6,1],
+"classCGAL_1_1Surface__mesh__parameterization_1_1Iterative__authalic__parameterizer__3.html#ae909913721b564a77736d7ec4a9df7cc":[1,0,3,6,4],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Iterative__authalic__parameterizer__3.html#af4a137e1f3f0aa0525f85317b45781ab":[1,0,3,6,2],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Iterative__authalic__parameterizer__3.html#afc14950b49095dce57480773ba38383a":[1,0,3,6,3],
-"classCGAL_1_1Surface__mesh__parameterization_1_1Iterative__authalic__parameterizer__3.html#afe21721b7db5b9f094aeb67f637c4c1e":[1,0,3,6,5],
 "classCGAL_1_1Surface__mesh__parameterization_1_1LSCM__parameterizer__3.html":[1,0,3,7],
 "classCGAL_1_1Surface__mesh__parameterization_1_1LSCM__parameterizer__3.html#a5baf91f7096ea149cabc8f394867b3c5":[1,0,3,7,6],
 "classCGAL_1_1Surface__mesh__parameterization_1_1LSCM__parameterizer__3.html#a913c8f00864a36b7a51222fe45803891":[1,0,3,7,1],
@@ -87,11 +85,11 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Surface__mesh__parameterization_1_1LSCM__parameterizer__3.html#ad2f63faf8a83edccb8d7e3bdc511ce04":[1,0,3,7,0],
 "classCGAL_1_1Surface__mesh__parameterization_1_1LSCM__parameterizer__3.html#ad39bd544f87d3f0293b5aaf0bfd4ae6d":[1,0,3,7,3],
 "classCGAL_1_1Surface__mesh__parameterization_1_1LSCM__parameterizer__3.html#af536dde5de6f5dbde9ee3c6f1cfbe7d6":[1,0,3,7,2],
-"classCGAL_1_1Surface__mesh__parameterization_1_1MVC__post__processor__3.html":[5,0,0,11],
-"classCGAL_1_1Surface__mesh__parameterization_1_1MVC__post__processor__3.html#a1def4710e300b66bd7b34db9391a9735":[5,0,0,11,0],
-"classCGAL_1_1Surface__mesh__parameterization_1_1MVC__post__processor__3.html#a699b33843f8aa569c5081875879416ef":[5,0,0,11,1],
-"classCGAL_1_1Surface__mesh__parameterization_1_1MVC__post__processor__3.html#a7ae9bb48971432079ee5ef211ee0cc19":[5,0,0,11,2],
-"classCGAL_1_1Surface__mesh__parameterization_1_1MVC__post__processor__3.html#ab8b59d4684d99e743bb0e469093714ce":[5,0,0,11,3],
+"classCGAL_1_1Surface__mesh__parameterization_1_1MVC__post__processor__3.html":[3,0,0,11],
+"classCGAL_1_1Surface__mesh__parameterization_1_1MVC__post__processor__3.html#a1def4710e300b66bd7b34db9391a9735":[3,0,0,11,0],
+"classCGAL_1_1Surface__mesh__parameterization_1_1MVC__post__processor__3.html#a699b33843f8aa569c5081875879416ef":[3,0,0,11,1],
+"classCGAL_1_1Surface__mesh__parameterization_1_1MVC__post__processor__3.html#a7ae9bb48971432079ee5ef211ee0cc19":[3,0,0,11,2],
+"classCGAL_1_1Surface__mesh__parameterization_1_1MVC__post__processor__3.html#ab8b59d4684d99e743bb0e469093714ce":[3,0,0,11,3],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Mean__value__coordinates__parameterizer__3.html":[1,0,3,8],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Mean__value__coordinates__parameterizer__3.html#a3412d97a93e239782f792e011eb5f8a5":[1,0,3,8,7],
 "classCGAL_1_1Surface__mesh__parameterization_1_1Mean__value__coordinates__parameterizer__3.html#a5297e37064b63d3d9b054d01f8789fc7":[1,0,3,8,5],
@@ -133,15 +131,15 @@ var NAVTREEINDEX0 =
 "classParameterizer__3.html":[1,0,2,0],
 "classParameterizer__3.html#a2d47e13038c2f42da7e63895e043edfc":[1,0,2,0,1],
 "classParameterizer__3.html#ab426623e392b654f97b8d14c69be5a29":[1,0,2,0,0],
-"examples.html":[6],
+"examples.html":[4],
 "group__PkgSurfaceMeshParameterizationBorderParameterizationMethods.html":[1,0,4],
 "group__PkgSurfaceMeshParameterizationConcepts.html":[1,0,2],
 "group__PkgSurfaceMeshParameterizationEnums.html":[1,0,1],
-"group__PkgSurfaceMeshParameterizationEnums.html#ga37b53162f5cb508857672cd249d16399":[1,0,1,4],
-"group__PkgSurfaceMeshParameterizationEnums.html#ga3d6f06bf05d490b9096ff8270c3bb3b5":[1,0,1,5],
+"group__PkgSurfaceMeshParameterizationEnums.html#ga784350037352beb75002bfa42f2febf7":[1,0,1,4],
 "group__PkgSurfaceMeshParameterizationEnums.html#ga992e12bb57ad83cbeb41ff2439669561":[1,0,1,3],
 "group__PkgSurfaceMeshParameterizationEnums.html#ga9bf015e651e33c9a5ac0be11d05eed19":[1,0,1,2],
 "group__PkgSurfaceMeshParameterizationEnums.html#gaae0686c0467daddc7328bcba2e1b5a5b":[1,0,1,0],
+"group__PkgSurfaceMeshParameterizationEnums.html#gae1cff0015dc945d18aced36e6bbad086":[1,0,1,5],
 "group__PkgSurfaceMeshParameterizationEnums.html#gaee614329039ca5fdba0e1059cd7d3e94":[1,0,1,1],
 "group__PkgSurfaceMeshParameterizationEnums.html#gga992e12bb57ad83cbeb41ff2439669561a3edb5b4f0f0ef9c72d4bc70752aa3ead":[1,0,1,3,1],
 "group__PkgSurfaceMeshParameterizationEnums.html#gga992e12bb57ad83cbeb41ff2439669561a4e7d1d391eb846790038dbf17183b2bb":[1,0,1,3,0],
@@ -163,22 +161,21 @@ var NAVTREEINDEX0 =
 "group__PkgSurfaceMeshParameterizationEnums.html#ggaee614329039ca5fdba0e1059cd7d3e94ae268995a76e411829253d4c4467643b3":[1,0,1,1,4],
 "group__PkgSurfaceMeshParameterizationEnums.html#ggaee614329039ca5fdba0e1059cd7d3e94af38b611f9584f27051e998e4826f656b":[1,0,1,1,1],
 "group__PkgSurfaceMeshParameterizationMainFunction.html":[1,0,0],
-"group__PkgSurfaceMeshParameterizationMainFunction.html#ga246acaaf92fb9e3926fae77e625ab0e5":[1,0,0,0],
-"group__PkgSurfaceMeshParameterizationMainFunction.html#gaf59093f653c62e7f5c04bb3be4fb1e22":[1,0,0,1],
+"group__PkgSurfaceMeshParameterizationMainFunction.html#ga246acaaf92fb9e3926fae77e625ab0e5":[1,0,0,1],
+"group__PkgSurfaceMeshParameterizationMainFunction.html#gaf59093f653c62e7f5c04bb3be4fb1e22":[1,0,0,0],
 "group__PkgSurfaceMeshParameterizationMethods.html":[1,0,3],
 "group__PkgSurfaceMeshParameterizationOrbifoldHelperFunctions.html":[1,0,3,0],
 "group__PkgSurfaceMeshParameterizationOrbifoldHelperFunctions.html#ga492d5817c0f14881b2cf774891158b6c":[1,0,3,0,3],
 "group__PkgSurfaceMeshParameterizationOrbifoldHelperFunctions.html#ga7999a1b655ef11c9173bc13050c8a4e6":[1,0,3,0,0],
 "group__PkgSurfaceMeshParameterizationOrbifoldHelperFunctions.html#ga7afcc810eb830de23cd823efac112cb4":[1,0,3,0,1],
-"group__PkgSurfaceMeshParameterizationOrbifoldHelperFunctions.html#ga7b700f3c4313454df4b02a50d6e32759":[1,0,3,0,5],
-"group__PkgSurfaceMeshParameterizationOrbifoldHelperFunctions.html#ga7e64b35e8b6dfe1845ee7a690f46cdfb":[1,0,3,0,4],
+"group__PkgSurfaceMeshParameterizationOrbifoldHelperFunctions.html#ga7b700f3c4313454df4b02a50d6e32759":[1,0,3,0,6],
+"group__PkgSurfaceMeshParameterizationOrbifoldHelperFunctions.html#ga7e64b35e8b6dfe1845ee7a690f46cdfb":[1,0,3,0,7],
 "group__PkgSurfaceMeshParameterizationOrbifoldHelperFunctions.html#ga99d241fa9d2d58eabd4c39025595e8ef":[1,0,3,0,2],
-"group__PkgSurfaceMeshParameterizationOrbifoldHelperFunctions.html#gad0af80615c11e326b92fc961c07a3f85":[1,0,3,0,6],
-"group__PkgSurfaceMeshParameterizationOrbifoldHelperFunctions.html#gad0df34361a011d2d11247818b22366d1":[1,0,3,0,7],
+"group__PkgSurfaceMeshParameterizationOrbifoldHelperFunctions.html#gad0af80615c11e326b92fc961c07a3f85":[1,0,3,0,5],
+"group__PkgSurfaceMeshParameterizationOrbifoldHelperFunctions.html#gad0df34361a011d2d11247818b22366d1":[1,0,3,0,4],
 "group__PkgSurfaceMeshParameterizationRef.html":[1,0],
-"hasModels.html":[3],
-"index.html":[0],
 "index.html":[],
+"index.html":[0],
 "index.html#Surface_mesh_parameterizationARAP":[0,2,1,1],
 "index.html#Surface_mesh_parameterizationBasics":[0,1],
 "index.html#Surface_mesh_parameterizationBorderless":[0,2,2],
@@ -202,7 +199,7 @@ var NAVTREEINDEX0 =
 "index.html#secBorderParameterizationsforFreeMethods":[0,2,1,2],
 "index.html#secCuttingaMesh":[0,3],
 "index.html#secSurfaceParameterizationMethods":[0,2],
-"models.html":[2],
 "modules.html":[1],
-"pages.html":[]
+"pages.html":[],
+"surface__mesh__parameterization_8h.html":[1,0,5]
 };
