@@ -22,16 +22,16 @@ var group__PkgTDS3Concepts =
       [ "TriangulationDataStructure_3", "classTriangulationDataStructure__3.html#a429b60de3f9efac2dea244a598406e54", null ],
       [ "TriangulationDataStructure_3", "classTriangulationDataStructure__3.html#a3361b1108ee78cdc13f54a37c29a44be", null ],
       [ "adjacent_vertices", "classTriangulationDataStructure__3.html#a5eb7787bb7661329a9b4e7ad3fc608ae", null ],
-      [ "are_equal", "classTriangulationDataStructure__3.html#a4e7c5fa5f7dfec7732ef659bd196734d", null ],
       [ "are_equal", "classTriangulationDataStructure__3.html#ab098c18e338af91ae9d4dc5a34a3ecab", null ],
       [ "are_equal", "classTriangulationDataStructure__3.html#af77651103747471b0f1b7d7b5c05ea32", null ],
+      [ "are_equal", "classTriangulationDataStructure__3.html#a4e7c5fa5f7dfec7732ef659bd196734d", null ],
       [ "cells_begin", "classTriangulationDataStructure__3.html#a5d92b7f62a307c8afb8abb1592fdd0d8", null ],
       [ "cells_end", "classTriangulationDataStructure__3.html#a6ce5cc0108e2af2ead45de9da8bf13f1", null ],
       [ "clear", "classTriangulationDataStructure__3.html#ae0069b70358e63a4e3c044b2f64e929d", null ],
-      [ "copy_tds", "classTriangulationDataStructure__3.html#a9414a96a16309179ad08a0f42f196e2e", null ],
       [ "copy_tds", "classTriangulationDataStructure__3.html#aac784b676421bd590612bb08c0a84f89", null ],
-      [ "create_cell", "classTriangulationDataStructure__3.html#a1432860206073c24ca43dbbdfb13b26e", null ],
+      [ "copy_tds", "classTriangulationDataStructure__3.html#a9414a96a16309179ad08a0f42f196e2e", null ],
       [ "create_cell", "classTriangulationDataStructure__3.html#a17b4a21b9f6b95334baa18fdb5598dbc", null ],
+      [ "create_cell", "classTriangulationDataStructure__3.html#a1432860206073c24ca43dbbdfb13b26e", null ],
       [ "create_cell", "classTriangulationDataStructure__3.html#aec0d8528e29ce73226d66d44237cf8c7", null ],
       [ "create_cell", "classTriangulationDataStructure__3.html#aee7bebae22e4fe9094b744d8ea54d28b", null ],
       [ "create_vertex", "classTriangulationDataStructure__3.html#a0fc1c3d4aa69c6411d240989dec0d7ff", null ],
@@ -47,50 +47,50 @@ var group__PkgTDS3Concepts =
       [ "edges_end", "classTriangulationDataStructure__3.html#a7dbaf55983cfdb81b1d7f43ac7f46699", null ],
       [ "facets_begin", "classTriangulationDataStructure__3.html#a2c32481f3e373ea2bbf7921c92d59dab", null ],
       [ "facets_end", "classTriangulationDataStructure__3.html#ac3bfe63c6a5202f262527bb03527139f", null ],
-      [ "file_input", "group__PkgIOTDS3.html#ga381446a02a9240cc83e79c48b37cd119", null ],
-      [ "flip", "classTriangulationDataStructure__3.html#a5837d666e4198f707f862003c1ffa033", null ],
-      [ "flip", "classTriangulationDataStructure__3.html#ae1dff464b3bce22c391f6e655b5add2b", null ],
-      [ "flip", "classTriangulationDataStructure__3.html#a35035785fb40f4580413e53289ce168e", null ],
+      [ "file_input", "group__PkgIOTDS3.html#ga7f9aec6be547c62b81f3bddec08e1581", null ],
       [ "flip", "classTriangulationDataStructure__3.html#a2ad2941984c1eac5561665700bfd60b4", null ],
-      [ "flip_flippable", "classTriangulationDataStructure__3.html#a2033a88a5e9e76580b52c483b49e94a5", null ],
-      [ "flip_flippable", "classTriangulationDataStructure__3.html#ab17d9dbb42f3fdb48b768d2756fea15d", null ],
-      [ "flip_flippable", "classTriangulationDataStructure__3.html#abdf5a4004ecc08decbaa69992e6a5652", null ],
+      [ "flip", "classTriangulationDataStructure__3.html#ae1dff464b3bce22c391f6e655b5add2b", null ],
+      [ "flip", "classTriangulationDataStructure__3.html#a5837d666e4198f707f862003c1ffa033", null ],
+      [ "flip", "classTriangulationDataStructure__3.html#a35035785fb40f4580413e53289ce168e", null ],
       [ "flip_flippable", "classTriangulationDataStructure__3.html#a0891ed2a1907f79a1d5427b77521d23a", null ],
-      [ "has_vertex", "classTriangulationDataStructure__3.html#a04230a686b1b95c72453becaa7aadfcb", null ],
+      [ "flip_flippable", "classTriangulationDataStructure__3.html#ab17d9dbb42f3fdb48b768d2756fea15d", null ],
+      [ "flip_flippable", "classTriangulationDataStructure__3.html#a2033a88a5e9e76580b52c483b49e94a5", null ],
+      [ "flip_flippable", "classTriangulationDataStructure__3.html#abdf5a4004ecc08decbaa69992e6a5652", null ],
+      [ "has_vertex", "classTriangulationDataStructure__3.html#a2b067e245a8d0da60d8d3be2e148a3dc", null ],
       [ "has_vertex", "classTriangulationDataStructure__3.html#a3be306b371a30dc354367514124935fd", null ],
       [ "has_vertex", "classTriangulationDataStructure__3.html#ad9accafc62ec371daa387d58f237691d", null ],
-      [ "has_vertex", "classTriangulationDataStructure__3.html#a2b067e245a8d0da60d8d3be2e148a3dc", null ],
-      [ "incident_cells", "classTriangulationDataStructure__3.html#a93f8ab30228b2a515a5c9cdacd9d4d36", null ],
+      [ "has_vertex", "classTriangulationDataStructure__3.html#a04230a686b1b95c72453becaa7aadfcb", null ],
       [ "incident_cells", "classTriangulationDataStructure__3.html#a531c8eef5aa5ab9c49ab328c014a679e", null ],
-      [ "incident_cells", "classTriangulationDataStructure__3.html#afbba273c688d4e08cf713b21f48e09a0", null ],
       [ "incident_cells", "classTriangulationDataStructure__3.html#a175cb1f4a6f826b99caf57915abb85f1", null ],
+      [ "incident_cells", "classTriangulationDataStructure__3.html#a93f8ab30228b2a515a5c9cdacd9d4d36", null ],
+      [ "incident_cells", "classTriangulationDataStructure__3.html#afbba273c688d4e08cf713b21f48e09a0", null ],
       [ "incident_cells", "classTriangulationDataStructure__3.html#a909d34e5c177dd9a76b357adbd051e5b", null ],
       [ "incident_edges", "classTriangulationDataStructure__3.html#a3d79d5f7d68a1f793d59939b128d52d5", null ],
-      [ "incident_facets", "classTriangulationDataStructure__3.html#ab1cdee0d617236024e0de968236ad4ad", null ],
       [ "incident_facets", "classTriangulationDataStructure__3.html#a33f555feb22c135bbc059a2235a7c414", null ],
-      [ "incident_facets", "classTriangulationDataStructure__3.html#a094ce9ce6cd049c07288bb02acb52c9e", null ],
-      [ "incident_facets", "classTriangulationDataStructure__3.html#a51abc6426d5df4a8766e56c50abfb53e", null ],
-      [ "incident_facets", "classTriangulationDataStructure__3.html#aafbfaffeb28ea8414aee1763271aff93", null ],
       [ "incident_facets", "classTriangulationDataStructure__3.html#a60d2859f025d619b4b4779b5a1dae01f", null ],
+      [ "incident_facets", "classTriangulationDataStructure__3.html#aafbfaffeb28ea8414aee1763271aff93", null ],
+      [ "incident_facets", "classTriangulationDataStructure__3.html#ab1cdee0d617236024e0de968236ad4ad", null ],
+      [ "incident_facets", "classTriangulationDataStructure__3.html#a51abc6426d5df4a8766e56c50abfb53e", null ],
+      [ "incident_facets", "classTriangulationDataStructure__3.html#a094ce9ce6cd049c07288bb02acb52c9e", null ],
       [ "incident_facets", "classTriangulationDataStructure__3.html#a69b083dd2feb9e6c0d289cad5c963851", null ],
       [ "insert_in_cell", "classTriangulationDataStructure__3.html#ad6076fbc62d2df3e7ff80f10477e45e7", null ],
-      [ "insert_in_edge", "classTriangulationDataStructure__3.html#a83e0de38dc74a748306453573e5bcfb5", null ],
       [ "insert_in_edge", "classTriangulationDataStructure__3.html#aff296730457731bb243ed50f62178017", null ],
-      [ "insert_in_facet", "classTriangulationDataStructure__3.html#ac3992727684758e91ea72b04613691af", null ],
+      [ "insert_in_edge", "classTriangulationDataStructure__3.html#a83e0de38dc74a748306453573e5bcfb5", null ],
       [ "insert_in_facet", "classTriangulationDataStructure__3.html#aa2c26664c41c84945b9988216fa9a2b4", null ],
+      [ "insert_in_facet", "classTriangulationDataStructure__3.html#ac3992727684758e91ea72b04613691af", null ],
       [ "insert_in_hole", "classTriangulationDataStructure__3.html#a48ff04c7b5755a4b82f28cb1b6507328", null ],
       [ "insert_in_hole", "classTriangulationDataStructure__3.html#a4d56ad9d2d2646e093e2288203b1a294", null ],
       [ "insert_increase_dimension", "classTriangulationDataStructure__3.html#a94f00b8fe946834c47f544016d2d7a5d", null ],
       [ "is_cell", "classTriangulationDataStructure__3.html#a995ab79f782886252430b1f61f89b288", null ],
       [ "is_cell", "classTriangulationDataStructure__3.html#a9916351c37824546ffb8131414ce4658", null ],
       [ "is_edge", "classTriangulationDataStructure__3.html#a8c9bdf0042b86083f3a72d983a941743", null ],
-      [ "is_edge", "classTriangulationDataStructure__3.html#a687158d9dd7f24fe6bbd794db2a9f59c", null ],
       [ "is_edge", "classTriangulationDataStructure__3.html#af420049d742ceffb903d3ed48aa684e0", null ],
+      [ "is_edge", "classTriangulationDataStructure__3.html#a687158d9dd7f24fe6bbd794db2a9f59c", null ],
       [ "is_facet", "classTriangulationDataStructure__3.html#ad22e99a146edae0ee1b2d01e911724ec", null ],
       [ "is_facet", "classTriangulationDataStructure__3.html#aed2a512ad3c5ed2c8fdc31fbbb029fc9", null ],
       [ "is_valid", "classTriangulationDataStructure__3.html#aa4c8fbaf1a700327e28d57c0c360f9b2", null ],
-      [ "is_valid", "classTriangulationDataStructure__3.html#aa7ed0a72d1846f651dfd1590ad9d44cf", null ],
       [ "is_valid", "classTriangulationDataStructure__3.html#a4161bdabd710d608994ff86527a79088", null ],
+      [ "is_valid", "classTriangulationDataStructure__3.html#aa7ed0a72d1846f651dfd1590ad9d44cf", null ],
       [ "is_vertex", "classTriangulationDataStructure__3.html#aa65f1686e98e1c839e438f178e5b5c45", null ],
       [ "mirror_facet", "classTriangulationDataStructure__3.html#af386d55822ab1d47703f4500d642a7f2", null ],
       [ "mirror_index", "classTriangulationDataStructure__3.html#a51dc4a918b2e1afe4f4fd93531ed337b", null ],
@@ -99,9 +99,9 @@ var group__PkgTDS3Concepts =
       [ "number_of_edges", "classTriangulationDataStructure__3.html#a2caedcb8a15d82292e09bf1c750bced6", null ],
       [ "number_of_facets", "classTriangulationDataStructure__3.html#a4ed740a0373ab4ba1f3c8a4899c2281b", null ],
       [ "number_of_vertices", "classTriangulationDataStructure__3.html#a856ac86dc9d70d550ee73b74af9a5e5f", null ],
-      [ "operator<<", "group__PkgIOTDS3.html#gad90ce2e95e385e8709301609ef32c2a2", null ],
-      [ "operator=", "classTriangulationDataStructure__3.html#a9e2525beb055eacec49c6bb5a1198fa3", null ],
-      [ "operator>>", "group__PkgIOTDS3.html#ga674d4f4d02e85cfbe30e5ca3bd769d69", null ],
+      [ "operator<<", "group__PkgIOTDS3.html#ga13941cbdb65047e071485853a7f619d9", null ],
+      [ "operator=", "classTriangulationDataStructure__3.html#a9a0a71c02047281a9e8ce510591c911b", null ],
+      [ "operator>>", "group__PkgIOTDS3.html#gad0f65f72d23f3dff3505a218e562e70b", null ],
       [ "raw_cells_begin", "classTriangulationDataStructure__3.html#a9b0197c963274f1fb57c8014545fdef8", null ],
       [ "raw_cells_end", "classTriangulationDataStructure__3.html#ab0569b5ce85fb023a323bf07b67c3f9d", null ],
       [ "remove_decrease_dimension", "classTriangulationDataStructure__3.html#a65b1f8ca49810b63670f5a77bfc64c87", null ],
@@ -112,38 +112,7 @@ var group__PkgTDS3Concepts =
       [ "vertices_begin", "classTriangulationDataStructure__3.html#a6c6e2b3dc6856094a8d8d39e3b6f41ee", null ],
       [ "vertices_end", "classTriangulationDataStructure__3.html#abf0911ecc801a5df71737c95ad29c968", null ]
     ] ],
-    [ "Cell_data", "classTriangulationDataStructure__3_1_1Cell__data.html", [
-      [ "clear", "classTriangulationDataStructure__3_1_1Cell__data.html#a3aecee93978934c41ad9ac0f8904f858", null ],
-      [ "is_clear", "classTriangulationDataStructure__3_1_1Cell__data.html#ac8bf1ce47ab93c81af1b8700963e4a5f", null ],
-      [ "is_in_conflict", "classTriangulationDataStructure__3_1_1Cell__data.html#a1e16f8eb3801c6a20fd5105cebbb7295", null ],
-      [ "is_on_boundary", "classTriangulationDataStructure__3_1_1Cell__data.html#a7463b09f382f8724cc0142f671b62374", null ],
-      [ "mark_in_conflict", "classTriangulationDataStructure__3_1_1Cell__data.html#a55b09214995d11d1d84b1b190e22ab03", null ],
-      [ "mark_on_boundary", "classTriangulationDataStructure__3_1_1Cell__data.html#aaacc93bbc4aa79a5805f3167210c14a7", null ],
-      [ "mark_processed", "classTriangulationDataStructure__3_1_1Cell__data.html#a9538762eba3a59dbf7fbfb9d409e72b9", null ],
-      [ "processed", "classTriangulationDataStructure__3_1_1Cell__data.html#ad897f96b2c261554c34a22782557f26f", null ]
-    ] ],
-    [ "Cell", "classTriangulationDataStructure__3_1_1Cell.html", [
-      [ "Cell_handle", "classTriangulationDataStructure__3_1_1Cell.html#a3b4662e89acf187148531f7d7c9259d3", null ],
-      [ "TDS_data", "classTriangulationDataStructure__3_1_1Cell.html#a40386403b8b3a0738f41e6f852d0872f", null ],
-      [ "Triangulation_data_structure", "classTriangulationDataStructure__3_1_1Cell.html#a176a89efe1c2bbc69e29af3ebce86c78", null ],
-      [ "Vertex_handle", "classTriangulationDataStructure__3_1_1Cell.html#ab857cc8603822dc6f48e3c3ed2d79245", null ],
-      [ "has_neighbor", "classTriangulationDataStructure__3_1_1Cell.html#aaae46298db6d36a20e515d422b34b623", null ],
-      [ "has_neighbor", "classTriangulationDataStructure__3_1_1Cell.html#ab2bac8adc170e5869f913c9507b9b679", null ],
-      [ "has_vertex", "classTriangulationDataStructure__3_1_1Cell.html#af236cc775053f6d09b514cc51febd8d3", null ],
-      [ "has_vertex", "classTriangulationDataStructure__3_1_1Cell.html#ac94bb36ecd104b1c656bc706a2807b27", null ],
-      [ "index", "classTriangulationDataStructure__3_1_1Cell.html#aab86f23d77c96617dde579fad127a159", null ],
-      [ "index", "classTriangulationDataStructure__3_1_1Cell.html#a06ca07731855b55035195db105442c79", null ],
-      [ "is_valid", "classTriangulationDataStructure__3_1_1Cell.html#a9f5328842009bc5f8be9270b9ba54821", null ],
-      [ "neighbor", "classTriangulationDataStructure__3_1_1Cell.html#a1276d9e37a1460e81f88f4ae33295cb8", null ],
-      [ "set_neighbor", "classTriangulationDataStructure__3_1_1Cell.html#ade09a118c23f3e5852eba6763bc4270b", null ],
-      [ "set_neighbors", "classTriangulationDataStructure__3_1_1Cell.html#ace214d6e7a06de2976adbbc18c90a0d1", null ],
-      [ "set_vertex", "classTriangulationDataStructure__3_1_1Cell.html#a7bcf518ef82cfe031ebef17312eb3c3b", null ],
-      [ "set_vertices", "classTriangulationDataStructure__3_1_1Cell.html#a04a65bf4f7b4dd5b36f534b1ff007a7e", null ],
-      [ "tds_data", "classTriangulationDataStructure__3_1_1Cell.html#ac5ed4802337f089c035ef0758cc5549b", null ],
-      [ "tds_data", "classTriangulationDataStructure__3_1_1Cell.html#afd20a803298675e768581d3aa4cf23fd", null ],
-      [ "vertex", "classTriangulationDataStructure__3_1_1Cell.html#a3bf1b23061c6afb32014fc0a24e490e5", null ]
-    ] ],
-    [ "Vertex", "classTriangulationDataStructure__3_1_1Vertex.html", [
+    [ "TriangulationDataStructure_3::Vertex", "classTriangulationDataStructure__3_1_1Vertex.html", [
       [ "Cell_handle", "classTriangulationDataStructure__3_1_1Vertex.html#a0058a4bae5802e4633644179bc6e5c95", null ],
       [ "Point", "classTriangulationDataStructure__3_1_1Vertex.html#a44a9b44c659ddb457db3f9e556e46970", null ],
       [ "Triangulation_data_structure", "classTriangulationDataStructure__3_1_1Vertex.html#aaa79f9a7574ebe6963620a7552b91419", null ],
@@ -154,6 +123,37 @@ var group__PkgTDS3Concepts =
       [ "set_cell", "classTriangulationDataStructure__3_1_1Vertex.html#a91e74aaa742d4cd4146892935f1d503a", null ],
       [ "set_point", "classTriangulationDataStructure__3_1_1Vertex.html#a6ab8b261adac3079809ff92e7c283ed3", null ]
     ] ],
+    [ "TriangulationDataStructure_3::Cell", "classTriangulationDataStructure__3_1_1Cell.html", [
+      [ "Cell_handle", "classTriangulationDataStructure__3_1_1Cell.html#a3b4662e89acf187148531f7d7c9259d3", null ],
+      [ "TDS_data", "classTriangulationDataStructure__3_1_1Cell.html#a40386403b8b3a0738f41e6f852d0872f", null ],
+      [ "Triangulation_data_structure", "classTriangulationDataStructure__3_1_1Cell.html#a176a89efe1c2bbc69e29af3ebce86c78", null ],
+      [ "Vertex_handle", "classTriangulationDataStructure__3_1_1Cell.html#ab857cc8603822dc6f48e3c3ed2d79245", null ],
+      [ "has_neighbor", "classTriangulationDataStructure__3_1_1Cell.html#aaae46298db6d36a20e515d422b34b623", null ],
+      [ "has_neighbor", "classTriangulationDataStructure__3_1_1Cell.html#ab2bac8adc170e5869f913c9507b9b679", null ],
+      [ "has_vertex", "classTriangulationDataStructure__3_1_1Cell.html#af236cc775053f6d09b514cc51febd8d3", null ],
+      [ "has_vertex", "classTriangulationDataStructure__3_1_1Cell.html#ac94bb36ecd104b1c656bc706a2807b27", null ],
+      [ "index", "classTriangulationDataStructure__3_1_1Cell.html#a06ca07731855b55035195db105442c79", null ],
+      [ "index", "classTriangulationDataStructure__3_1_1Cell.html#aab86f23d77c96617dde579fad127a159", null ],
+      [ "is_valid", "classTriangulationDataStructure__3_1_1Cell.html#a9f5328842009bc5f8be9270b9ba54821", null ],
+      [ "neighbor", "classTriangulationDataStructure__3_1_1Cell.html#a1276d9e37a1460e81f88f4ae33295cb8", null ],
+      [ "set_neighbor", "classTriangulationDataStructure__3_1_1Cell.html#ade09a118c23f3e5852eba6763bc4270b", null ],
+      [ "set_neighbors", "classTriangulationDataStructure__3_1_1Cell.html#ace214d6e7a06de2976adbbc18c90a0d1", null ],
+      [ "set_vertex", "classTriangulationDataStructure__3_1_1Cell.html#a7bcf518ef82cfe031ebef17312eb3c3b", null ],
+      [ "set_vertices", "classTriangulationDataStructure__3_1_1Cell.html#a04a65bf4f7b4dd5b36f534b1ff007a7e", null ],
+      [ "tds_data", "classTriangulationDataStructure__3_1_1Cell.html#a6254f315656203c13b42c747b085a8f3", null ],
+      [ "tds_data", "classTriangulationDataStructure__3_1_1Cell.html#a879204c4fcd3335ff479c0572ca97814", null ],
+      [ "vertex", "classTriangulationDataStructure__3_1_1Cell.html#a3bf1b23061c6afb32014fc0a24e490e5", null ]
+    ] ],
+    [ "TriangulationDataStructure_3::Cell_data", "classTriangulationDataStructure__3_1_1Cell__data.html", [
+      [ "clear", "classTriangulationDataStructure__3_1_1Cell__data.html#a3aecee93978934c41ad9ac0f8904f858", null ],
+      [ "is_clear", "classTriangulationDataStructure__3_1_1Cell__data.html#ac8bf1ce47ab93c81af1b8700963e4a5f", null ],
+      [ "is_in_conflict", "classTriangulationDataStructure__3_1_1Cell__data.html#a1e16f8eb3801c6a20fd5105cebbb7295", null ],
+      [ "is_on_boundary", "classTriangulationDataStructure__3_1_1Cell__data.html#a7463b09f382f8724cc0142f671b62374", null ],
+      [ "mark_in_conflict", "classTriangulationDataStructure__3_1_1Cell__data.html#a55b09214995d11d1d84b1b190e22ab03", null ],
+      [ "mark_on_boundary", "classTriangulationDataStructure__3_1_1Cell__data.html#aaacc93bbc4aa79a5805f3167210c14a7", null ],
+      [ "mark_processed", "classTriangulationDataStructure__3_1_1Cell__data.html#a9538762eba3a59dbf7fbfb9d409e72b9", null ],
+      [ "processed", "classTriangulationDataStructure__3_1_1Cell__data.html#ad897f96b2c261554c34a22782557f26f", null ]
+    ] ],
     [ "TriangulationDSCellBase_3", "classTriangulationDSCellBase__3.html", [
       [ "Cell_handle", "classTriangulationDSCellBase__3.html#af7048b8359597db1f73f37e1fa04be01", null ],
       [ "Rebind_TDS", "classTriangulationDSCellBase__3.html#a3a61786954b05d5664468d06a1543c2a", null ],
@@ -162,11 +162,11 @@ var group__PkgTDS3Concepts =
       [ "TriangulationDSCellBase_3", "classTriangulationDSCellBase__3.html#a88f3979f6cf05a4ceed64fcaa7123f0c", null ],
       [ "TriangulationDSCellBase_3", "classTriangulationDSCellBase__3.html#a41f187c2be08dd39b4b7d63d780121bd", null ],
       [ "TriangulationDSCellBase_3", "classTriangulationDSCellBase__3.html#a05ae0418569d0a0c210e26ea5997d8f4", null ],
-      [ "for_compact_container", "classTriangulationDSCellBase__3.html#af3931ebbdef46ca0ee6250eb93e55d12", null ],
+      [ "for_compact_container", "classTriangulationDSCellBase__3.html#af66d2c1b96aeb34c0ce03975f67b346c", null ],
       [ "for_compact_container", "classTriangulationDSCellBase__3.html#a488194ca741be3d39fcb2178d7670d2c", null ],
       [ "is_valid", "classTriangulationDSCellBase__3.html#a4a5e6fbfedd0e67a36d0ae287695d09c", null ],
-      [ "operator<<", "classTriangulationDSCellBase__3.html#a09074526564606eb80a784b26299d11c", null ],
-      [ "operator>>", "classTriangulationDSCellBase__3.html#afa0d9a575c27bcea294c34abc051b567", null ]
+      [ "operator<<", "classTriangulationDSCellBase__3.html#a91c2198b92a4f8df0ea7df2545df7478", null ],
+      [ "operator>>", "classTriangulationDSCellBase__3.html#a3f2030fe2b16ce0e65a55d03cf096c7c", null ]
     ] ],
     [ "TriangulationDSVertexBase_3", "classTriangulationDSVertexBase__3.html", [
       [ "Cell_handle", "classTriangulationDSVertexBase__3.html#adf7dfac9a840c3ab6aadb89e1a7ecdeb", null ],
@@ -175,10 +175,10 @@ var group__PkgTDS3Concepts =
       [ "Vertex_handle", "classTriangulationDSVertexBase__3.html#ad17f7b390a370dbce4f0b55baa1442d1", null ],
       [ "TriangulationDSVertexBase_3", "classTriangulationDSVertexBase__3.html#a869c20ee0463d3e329b40a716c929bae", null ],
       [ "TriangulationDSVertexBase_3", "classTriangulationDSVertexBase__3.html#af92290513cd47e1310a98fcb20938d1c", null ],
-      [ "for_compact_container", "classTriangulationDSVertexBase__3.html#a09613cf18061ad70e329524ce8ca55db", null ],
+      [ "for_compact_container", "classTriangulationDSVertexBase__3.html#a30b0bc7c820f97dc73cb06ddb7e2422d", null ],
       [ "for_compact_container", "classTriangulationDSVertexBase__3.html#a24ff23f07d50fbbcf31e73a5201b941b", null ],
       [ "is_valid", "classTriangulationDSVertexBase__3.html#a8275cd68244b9e5aa11313056835ca89", null ],
-      [ "operator<<", "classTriangulationDSVertexBase__3.html#a0d51fcc197ad7a316853781d32312da1", null ],
-      [ "operator>>", "classTriangulationDSVertexBase__3.html#a88175915d3665bbeb1b559d1ce6ca952", null ]
+      [ "operator<<", "classTriangulationDSVertexBase__3.html#a27648fe10a1f6c52dca0b607c7abc3fc", null ],
+      [ "operator>>", "classTriangulationDSVertexBase__3.html#a7ab4bf1cb28c894b5d5b5467d0dd7704", null ]
     ] ]
 ];
\ No newline at end of file
