@@ -67,12 +67,12 @@ var classCGAL_1_1Triangulation__3 =
     [ "all_vertices_begin", "classCGAL_1_1Triangulation__3.html#aba04013896bdd4ea1398320869e2d886", null ],
     [ "all_vertices_end", "classCGAL_1_1Triangulation__3.html#a8f2932dc2d9c018421d195757d9c5ffa", null ],
     [ "are_equal", "classCGAL_1_1Triangulation__3.html#a04ae7357b56d2bc5bd18c657e5577f79", null ],
-    [ "are_equal", "classCGAL_1_1Triangulation__3.html#a0460db28850be85188a8dec7c2425c3d", null ],
     [ "are_equal", "classCGAL_1_1Triangulation__3.html#a9f0c69f352b9e7fd325980807778b031", null ],
+    [ "are_equal", "classCGAL_1_1Triangulation__3.html#a0460db28850be85188a8dec7c2425c3d", null ],
     [ "clear", "classCGAL_1_1Triangulation__3.html#a0713863e5ff5ceb0a0eb290c4f6767c8", null ],
     [ "degree", "classCGAL_1_1Triangulation__3.html#a158716f1ea0f94c5f837a5ae244e2fe3", null ],
     [ "dimension", "classCGAL_1_1Triangulation__3.html#a80ba1634c96f534d18d2d2420f65561f", null ],
-    [ "file_input", "group__PkgIOTriangulation3.html#gadd94d0613e2dd9cdd2e88d2c74d5b1c8", null ],
+    [ "file_input", "group__PkgIOTriangulation3.html#ga20493e5839004e16ccd5929397b2ec75", null ],
     [ "finite_adjacent_vertices", "classCGAL_1_1Triangulation__3.html#af779084dce02eb4abba8bd1916891214", null ],
     [ "finite_cell_handles", "classCGAL_1_1Triangulation__3.html#ab9584da45f55288fb2b9d0624250bbf3", null ],
     [ "finite_cells_begin", "classCGAL_1_1Triangulation__3.html#a433fa868d7637f2719a40c251bd2ae65", null ],
@@ -89,68 +89,68 @@ var classCGAL_1_1Triangulation__3 =
     [ "finite_vertex_handles", "classCGAL_1_1Triangulation__3.html#a33a4aa893719a091df83ee40ad63a49f", null ],
     [ "finite_vertices_begin", "classCGAL_1_1Triangulation__3.html#af43b5f09e0fdcb9b8fff939133f2e814", null ],
     [ "finite_vertices_end", "classCGAL_1_1Triangulation__3.html#a6bff5471a8bd32d16c396948fdbc3495", null ],
-    [ "flip", "classCGAL_1_1Triangulation__3.html#a883fed00b53cae9e85feb20230f54dd9", null ],
-    [ "flip", "classCGAL_1_1Triangulation__3.html#a5dfdcfc38bf0bf30860d26d0fef7fdc7", null ],
-    [ "flip", "classCGAL_1_1Triangulation__3.html#a659e70e1b740a44b7d6b9886d323f571", null ],
     [ "flip", "classCGAL_1_1Triangulation__3.html#a8050a0e63dcf0fed2e205ce69b0fa2fe", null ],
-    [ "flip_flippable", "classCGAL_1_1Triangulation__3.html#a54b04cf190a4643d43dd67cd808b7fad", null ],
-    [ "flip_flippable", "classCGAL_1_1Triangulation__3.html#ac31682068c1ff25dc5ccd6f366fd1156", null ],
-    [ "flip_flippable", "classCGAL_1_1Triangulation__3.html#a2547de40ced9bfa49e16ff4ba2e1c52f", null ],
+    [ "flip", "classCGAL_1_1Triangulation__3.html#a5dfdcfc38bf0bf30860d26d0fef7fdc7", null ],
+    [ "flip", "classCGAL_1_1Triangulation__3.html#a883fed00b53cae9e85feb20230f54dd9", null ],
+    [ "flip", "classCGAL_1_1Triangulation__3.html#a659e70e1b740a44b7d6b9886d323f571", null ],
     [ "flip_flippable", "classCGAL_1_1Triangulation__3.html#a1d8720ff50a61985bcbe474268d9d275", null ],
-    [ "geom_traits", "classCGAL_1_1Triangulation__3.html#a5fda3a9a54f244f864d0f711f6ba90d6", null ],
-    [ "has_vertex", "classCGAL_1_1Triangulation__3.html#a89a5c93d1e8a43cef317ef289f1d5482", null ],
+    [ "flip_flippable", "classCGAL_1_1Triangulation__3.html#ac31682068c1ff25dc5ccd6f366fd1156", null ],
+    [ "flip_flippable", "classCGAL_1_1Triangulation__3.html#a54b04cf190a4643d43dd67cd808b7fad", null ],
+    [ "flip_flippable", "classCGAL_1_1Triangulation__3.html#a2547de40ced9bfa49e16ff4ba2e1c52f", null ],
+    [ "geom_traits", "classCGAL_1_1Triangulation__3.html#a230ff1dd66791a699820d9865b5a8f4d", null ],
+    [ "has_vertex", "classCGAL_1_1Triangulation__3.html#a9d997837c2cb5ecca65658ccf6dc3010", null ],
     [ "has_vertex", "classCGAL_1_1Triangulation__3.html#abf51c96f47c1e295fb984ad521634229", null ],
     [ "has_vertex", "classCGAL_1_1Triangulation__3.html#a21e33ef0b19042320b461a0a7a0f4e36", null ],
-    [ "has_vertex", "classCGAL_1_1Triangulation__3.html#a9d997837c2cb5ecca65658ccf6dc3010", null ],
-    [ "incident_cells", "classCGAL_1_1Triangulation__3.html#a0741a861a6291131384529349cb994a4", null ],
+    [ "has_vertex", "classCGAL_1_1Triangulation__3.html#a89a5c93d1e8a43cef317ef289f1d5482", null ],
     [ "incident_cells", "classCGAL_1_1Triangulation__3.html#a49921c82183b7bfdb5fac1de73c8d941", null ],
-    [ "incident_cells", "classCGAL_1_1Triangulation__3.html#a85d53f656ef4d67ccbf6eaed424e0a35", null ],
     [ "incident_cells", "classCGAL_1_1Triangulation__3.html#afd3ed4f0381fdeefb8a9439caa435b2f", null ],
+    [ "incident_cells", "classCGAL_1_1Triangulation__3.html#a0741a861a6291131384529349cb994a4", null ],
+    [ "incident_cells", "classCGAL_1_1Triangulation__3.html#a85d53f656ef4d67ccbf6eaed424e0a35", null ],
     [ "incident_cells", "classCGAL_1_1Triangulation__3.html#ad9890c64030969cd74f35a007cb6b049", null ],
     [ "incident_edges", "classCGAL_1_1Triangulation__3.html#a81373c29a596ba2f1d6d93e62d1f0d79", null ],
-    [ "incident_facets", "classCGAL_1_1Triangulation__3.html#a997be4328927428bce5aee9f775e5e55", null ],
     [ "incident_facets", "classCGAL_1_1Triangulation__3.html#abdf765a8077bfc18de39734fbe7ab012", null ],
-    [ "incident_facets", "classCGAL_1_1Triangulation__3.html#a1cbaaed93e5d67671302649501585a98", null ],
-    [ "incident_facets", "classCGAL_1_1Triangulation__3.html#a4cc635bb45ddcb7c1ab46f90592425d2", null ],
-    [ "incident_facets", "classCGAL_1_1Triangulation__3.html#a5d41217a20ef2851d44315b5166eaf76", null ],
     [ "incident_facets", "classCGAL_1_1Triangulation__3.html#a5d490167eab1facd3ef982613eb5d242", null ],
+    [ "incident_facets", "classCGAL_1_1Triangulation__3.html#a5d41217a20ef2851d44315b5166eaf76", null ],
+    [ "incident_facets", "classCGAL_1_1Triangulation__3.html#a997be4328927428bce5aee9f775e5e55", null ],
+    [ "incident_facets", "classCGAL_1_1Triangulation__3.html#a4cc635bb45ddcb7c1ab46f90592425d2", null ],
+    [ "incident_facets", "classCGAL_1_1Triangulation__3.html#a1cbaaed93e5d67671302649501585a98", null ],
     [ "incident_facets", "classCGAL_1_1Triangulation__3.html#a2776f24c7e4cdefc0c511edebf1d3599", null ],
     [ "inexact_locate", "classCGAL_1_1Triangulation__3.html#af33632f0d268cc25d0df2caa57f69609", null ],
     [ "infinite_cell", "classCGAL_1_1Triangulation__3.html#a4ef94a8a137601e4cb1905dcdad16c6c", null ],
     [ "infinite_vertex", "classCGAL_1_1Triangulation__3.html#a0dde82d53bcd9f705f3a676329c1df2d", null ],
     [ "insert", "classCGAL_1_1Triangulation__3.html#ad8d7a1aa3b310ba8d86ede726746fcb3", null ],
-    [ "insert", "classCGAL_1_1Triangulation__3.html#a579619f972362fa8cd35d1de72dd677c", null ],
     [ "insert", "classCGAL_1_1Triangulation__3.html#af41ac521888fafda75100fcd36650aa4", null ],
+    [ "insert", "classCGAL_1_1Triangulation__3.html#a579619f972362fa8cd35d1de72dd677c", null ],
     [ "insert", "classCGAL_1_1Triangulation__3.html#ad3353128386bbb51f79d0263e7f67337", null ],
     [ "insert", "classCGAL_1_1Triangulation__3.html#a8aa85f88733d30aa3ec5385538e13ace", null ],
     [ "insert_in_cell", "classCGAL_1_1Triangulation__3.html#aff8be2085c18e293f6d1a26c282acbc7", null ],
-    [ "insert_in_edge", "classCGAL_1_1Triangulation__3.html#a5c1349d7fcffeac6f98cfc8b8febf564", null ],
     [ "insert_in_edge", "classCGAL_1_1Triangulation__3.html#a06ba9d64000edc9e5d595ae1c7595922", null ],
-    [ "insert_in_facet", "classCGAL_1_1Triangulation__3.html#a80f8771ed8bca545ca451afae14b77ed", null ],
+    [ "insert_in_edge", "classCGAL_1_1Triangulation__3.html#a5c1349d7fcffeac6f98cfc8b8febf564", null ],
     [ "insert_in_facet", "classCGAL_1_1Triangulation__3.html#aa43e9ac9d97a9a2fa18ae18e21bb25b3", null ],
+    [ "insert_in_facet", "classCGAL_1_1Triangulation__3.html#a80f8771ed8bca545ca451afae14b77ed", null ],
     [ "insert_in_hole", "classCGAL_1_1Triangulation__3.html#a4b298ac4b2d8585dec9e436bb9e65ff0", null ],
     [ "insert_in_hole", "classCGAL_1_1Triangulation__3.html#ad5f7bba4f49683befd2f70b35f2d7079", null ],
     [ "insert_outside_affine_hull", "classCGAL_1_1Triangulation__3.html#a6f3e038498843f6ce7c0c70015ddaff9", null ],
     [ "insert_outside_convex_hull", "classCGAL_1_1Triangulation__3.html#a2798aa7502b4929ccaa8cab9bacbff18", null ],
     [ "is_cell", "classCGAL_1_1Triangulation__3.html#a0b9e348637a4c392f71fed0ef3ff2ad8", null ],
-    [ "is_cell", "classCGAL_1_1Triangulation__3.html#a24095561c8bd3390a58f7b7c9e45d4eb", null ],
     [ "is_cell", "classCGAL_1_1Triangulation__3.html#a8766c9a0c2a84203be31537e5e015646", null ],
+    [ "is_cell", "classCGAL_1_1Triangulation__3.html#a24095561c8bd3390a58f7b7c9e45d4eb", null ],
     [ "is_edge", "classCGAL_1_1Triangulation__3.html#a55b3dd5c4161a2612bd8aa60d64fb4f1", null ],
     [ "is_facet", "classCGAL_1_1Triangulation__3.html#aef7c688eb2a28c0aec936c41df46a172", null ],
-    [ "is_infinite", "classCGAL_1_1Triangulation__3.html#a0a5aa10a1bb88f33b3f07d33f89dd5cc", null ],
     [ "is_infinite", "classCGAL_1_1Triangulation__3.html#a8bc2a0fa204265bf32f1e6dc103988b4", null ],
     [ "is_infinite", "classCGAL_1_1Triangulation__3.html#ad66e030d66fdf1ee66e4c280e8894c71", null ],
-    [ "is_infinite", "classCGAL_1_1Triangulation__3.html#a0ece46e036b7dabfd34fd4662973e221", null ],
     [ "is_infinite", "classCGAL_1_1Triangulation__3.html#ab84793de9c9899d8ecc33cdac411d324", null ],
     [ "is_infinite", "classCGAL_1_1Triangulation__3.html#a6ca23f6bdd390ac23e7829e7f326efd5", null ],
+    [ "is_infinite", "classCGAL_1_1Triangulation__3.html#a0ece46e036b7dabfd34fd4662973e221", null ],
+    [ "is_infinite", "classCGAL_1_1Triangulation__3.html#a0a5aa10a1bb88f33b3f07d33f89dd5cc", null ],
     [ "is_valid", "classCGAL_1_1Triangulation__3.html#a76fa2f93b007c62d2c9d8deb09d8c5aa", null ],
     [ "is_valid", "classCGAL_1_1Triangulation__3.html#a57226e0d36b9fb236a0d6711cda456d0", null ],
     [ "is_vertex", "classCGAL_1_1Triangulation__3.html#a5b45572c663e5d2c10f26e7be421e140", null ],
     [ "is_vertex", "classCGAL_1_1Triangulation__3.html#a1d1c9daa1c2031a66c9acc0a958bdb8e", null ],
     [ "locate", "classCGAL_1_1Triangulation__3.html#a02a4a18074670282f3704f32b0901fad", null ],
-    [ "locate", "classCGAL_1_1Triangulation__3.html#a573cd639a2fdb12f400c0074597a5adc", null ],
     [ "locate", "classCGAL_1_1Triangulation__3.html#a384e93b6ff4614ed3b35bcf8981520c7", null ],
     [ "locate", "classCGAL_1_1Triangulation__3.html#ae26c070d4e465b8c6f95d63318080fe7", null ],
+    [ "locate", "classCGAL_1_1Triangulation__3.html#a573cd639a2fdb12f400c0074597a5adc", null ],
     [ "mirror_facet", "classCGAL_1_1Triangulation__3.html#ae443600f92d600b8e7d63a7fe2b5220c", null ],
     [ "mirror_index", "classCGAL_1_1Triangulation__3.html#a74cfefe0ac5dbe8e734461cda606a189", null ],
     [ "mirror_vertex", "classCGAL_1_1Triangulation__3.html#a35ba5a05076bfeb5357ccdc182b12fee", null ],
@@ -162,37 +162,40 @@ var classCGAL_1_1Triangulation__3 =
     [ "number_of_finite_facets", "classCGAL_1_1Triangulation__3.html#af332a576da991acf508cbd4473249e0b", null ],
     [ "number_of_vertices", "classCGAL_1_1Triangulation__3.html#a065228f3255a5d41d096fe782b61669f", null ],
     [ "operator!=", "classCGAL_1_1Triangulation__3.html#afe3483443d5cc96aec2f0603095b95f5", null ],
-    [ "operator<<", "group__PkgIOTriangulation3.html#ga0c1a9ffba823502938c0c87ff91edbd4", null ],
-    [ "operator=", "classCGAL_1_1Triangulation__3.html#ac33649b83bd5c708f5157286cc263c60", null ],
+    [ "operator<<", "group__PkgIOTriangulation3.html#gaf38f71bfe4880acf5f41844a5204997e", null ],
+    [ "operator=", "classCGAL_1_1Triangulation__3.html#abc8aafe82c32f53203d8d97069ef838d", null ],
     [ "operator==", "classCGAL_1_1Triangulation__3.html#a20b6e473c9ba697893aed432ba3d9754", null ],
-    [ "operator>>", "group__PkgIOTriangulation3.html#gabb84b5cde2cbb8c580790c10f3f0ddbb", null ],
-    [ "point", "classCGAL_1_1Triangulation__3.html#a32b9a309996aefea6e958e8380a33daf", null ],
-    [ "point", "classCGAL_1_1Triangulation__3.html#a482336074079c22dd94a5b66e60f775c", null ],
+    [ "operator>>", "group__PkgIOTriangulation3.html#gaeea8fffe7fd436b5613b31b973f89563", null ],
+    [ "point", "classCGAL_1_1Triangulation__3.html#ad19deb77eb94761e9bf0934f39cb3fa5", null ],
+    [ "point", "classCGAL_1_1Triangulation__3.html#a914f44aa77c5096630f94af46f98cab5", null ],
     [ "points", "classCGAL_1_1Triangulation__3.html#ae0b4d6177ffbcbd6c6d58820df53b746", null ],
     [ "points_begin", "classCGAL_1_1Triangulation__3.html#a067b365119a53428aff40652e0ccb400", null ],
     [ "points_end", "classCGAL_1_1Triangulation__3.html#ac69f365fe85f589224868cdfc859c078", null ],
-    [ "segment", "classCGAL_1_1Triangulation__3.html#a22bb4874ea8dc28c07584f1f55628707", null ],
     [ "segment", "classCGAL_1_1Triangulation__3.html#ae28b76ae0e1f364fc55d1b67f5b57249", null ],
+    [ "segment", "classCGAL_1_1Triangulation__3.html#a22bb4874ea8dc28c07584f1f55628707", null ],
     [ "segment_traverser_cell_handles", "classCGAL_1_1Triangulation__3.html#a7245a46ae480496e8e7e83fb2a1ebb43", null ],
-    [ "segment_traverser_cells_begin", "classCGAL_1_1Triangulation__3.html#a7b020f2841ad9a6148e79ac0939b06ec", null ],
     [ "segment_traverser_cells_begin", "classCGAL_1_1Triangulation__3.html#a535b21fc57d175507facde8091852d3c", null ],
+    [ "segment_traverser_cells_begin", "classCGAL_1_1Triangulation__3.html#a7b020f2841ad9a6148e79ac0939b06ec", null ],
     [ "segment_traverser_cells_end", "classCGAL_1_1Triangulation__3.html#adb5f31ae685c84289b0d39c2c1b3cf3b", null ],
     [ "segment_traverser_simplices", "classCGAL_1_1Triangulation__3.html#a5bb68143601dda95a446ee55cc7aa200", null ],
-    [ "segment_traverser_simplices_begin", "classCGAL_1_1Triangulation__3.html#a31e80cca5efe64571de4017067299449", null ],
     [ "segment_traverser_simplices_begin", "classCGAL_1_1Triangulation__3.html#a12b4b5511ee276cc341b940971e4544e", null ],
+    [ "segment_traverser_simplices_begin", "classCGAL_1_1Triangulation__3.html#a31e80cca5efe64571de4017067299449", null ],
     [ "segment_traverser_simplices_end", "classCGAL_1_1Triangulation__3.html#a2e5c7f41baa13b4086fe30ddb90f2c19", null ],
     [ "set_infinite_vertex", "classCGAL_1_1Triangulation__3.html#af50326c40f34f13a01bb0fd0935301f0", null ],
     [ "set_lock_data_structure", "classCGAL_1_1Triangulation__3.html#afba384e440c57f3bb0a71e4b4f7f9944", null ],
     [ "side_of_cell", "classCGAL_1_1Triangulation__3.html#a0ad86d1f011118565cbef93ad35d673b", null ],
-    [ "side_of_edge", "classCGAL_1_1Triangulation__3.html#a3155746fefa1a1f87a834b4d575c904b", null ],
     [ "side_of_edge", "classCGAL_1_1Triangulation__3.html#a60b867e74736abf01e8ce50e13c0aa9a", null ],
-    [ "side_of_facet", "classCGAL_1_1Triangulation__3.html#a6f26ad9ce68fbe3cb97ed211a68ab21f", null ],
+    [ "side_of_edge", "classCGAL_1_1Triangulation__3.html#a3155746fefa1a1f87a834b4d575c904b", null ],
     [ "side_of_facet", "classCGAL_1_1Triangulation__3.html#a4b2b97440867950f7a7723262bf93462", null ],
+    [ "side_of_facet", "classCGAL_1_1Triangulation__3.html#a6f26ad9ce68fbe3cb97ed211a68ab21f", null ],
     [ "swap", "classCGAL_1_1Triangulation__3.html#a767066a964b4d7b14376e5f5d1a04b34", null ],
-    [ "tds", "classCGAL_1_1Triangulation__3.html#ac00984a034bfe3b0f149498143ce76c8", null ],
-    [ "tds", "classCGAL_1_1Triangulation__3.html#ac6bd2d6740346b20377028653111b918", null ],
+    [ "tds", "classCGAL_1_1Triangulation__3.html#a951781437d62955aaae730b87c833498", null ],
+    [ "tds", "classCGAL_1_1Triangulation__3.html#a2caf4005a4dc8a221bfee2e4aeec569e", null ],
     [ "tetrahedron", "classCGAL_1_1Triangulation__3.html#a83d347f8d914b78f17f6817fdb0b7a14", null ],
     [ "triangle", "classCGAL_1_1Triangulation__3.html#ac2efcfbc0dcef89c512f65e4d13d4563", null ],
     [ "triangle", "classCGAL_1_1Triangulation__3.html#a6f9a07c130cde8a27869944396ab09e7", null ],
-    [ "try_lock_and_get_incident_cells", "classCGAL_1_1Triangulation__3.html#ace9dd63ba3a24d11d9b829198e514535", null ]
+    [ "try_lock_and_get_incident_cells", "classCGAL_1_1Triangulation__3.html#ace9dd63ba3a24d11d9b829198e514535", null ],
+    [ "vertices", "classCGAL_1_1Triangulation__3.html#a32a502a7555b5c77967ea3004a0d5c1c", null ],
+    [ "vertices", "classCGAL_1_1Triangulation__3.html#a02faf334255e1ca8caa1a6f412533759", null ],
+    [ "vertices", "classCGAL_1_1Triangulation__3.html#a539aa6bbb70ea430c787ee7e3600e064", null ]
 ];
\ No newline at end of file
