@@ -1,9 +1,9 @@
 var examples =
 [
-    [ "Weights/convergence.cpp", "Weights_2convergence_8cpp-example.html", null ],
-    [ "Weights/coordinates_multiple_queries.cpp", "Weights_2coordinates_multiple_queries_8cpp-example.html", null ],
+    [ "Weights/weights.cpp", "Weights_2weights_8cpp-example.html", null ],
     [ "Weights/coordinates_one_query.cpp", "Weights_2coordinates_one_query_8cpp-example.html", null ],
-    [ "Weights/custom_traits.cpp", "Weights_2custom_traits_8cpp-example.html", null ],
+    [ "Weights/coordinates_multiple_queries.cpp", "Weights_2coordinates_multiple_queries_8cpp-example.html", null ],
     [ "Weights/weighted_laplacian.cpp", "Weights_2weighted_laplacian_8cpp-example.html", null ],
-    [ "Weights/weights.cpp", "Weights_2weights_8cpp-example.html", null ]
+    [ "Weights/custom_traits.cpp", "Weights_2custom_traits_8cpp-example.html", null ],
+    [ "Weights/convergence.cpp", "Weights_2convergence_8cpp-example.html", null ]
 ];
\ No newline at end of file
